@@ -4,21 +4,21 @@ import logging
 from astropy.coordinates import SkyCoord
 from astropy.table import Table
 from regions import CircleSkyRegion
-import yaml
 from gammapy.analysis.config import AnalysisConfig
-from gammapy.cube import MapDataset, MapDatasetMaker, SafeMaskMaker
 from gammapy.data import DataStore
-from gammapy.maps import Map, MapAxis, WcsGeom
-from gammapy.modeling import Datasets, Fit
-from gammapy.modeling.models import Models
-from gammapy.modeling.serialize import dict_to_models
-from gammapy.spectrum import (
-    FluxPointsDataset,
-    FluxPointsEstimator,
+from gammapy.datasets import Datasets, FluxPointsDataset, MapDataset, SpectrumDataset
+from gammapy.estimators import FluxPointsEstimator
+from gammapy.makers import (
+    FoVBackgroundMaker,
+    MapDatasetMaker,
     ReflectedRegionsBackgroundMaker,
-    SpectrumDataset,
+    RingBackgroundMaker,
+    SafeMaskMaker,
     SpectrumDatasetMaker,
 )
+from gammapy.maps import Map, MapAxis, WcsGeom
+from gammapy.modeling import Fit
+from gammapy.modeling.models import BackgroundModel, Models
 from gammapy.utils.scripts import make_path
 
 __all__ = ["Analysis"]
@@ -69,7 +69,8 @@ class Analysis:
 
     def get_observations(self):
         """Fetch observations from the data store according to criteria defined in the configuration."""
-        path = make_path(self.config.observations.datastore)
+        observations_settings = self.config.observations
+        path = make_path(observations_settings.datastore)
         if path.is_file():
             self.datastore = DataStore.from_file(path)
         elif path.is_dir():
@@ -78,7 +79,6 @@ class Analysis:
             raise FileNotFoundError(f"Datastore not found: {path}")
 
         log.info("Fetching observations.")
-        observations_settings = self.config.observations
         if (
             len(observations_settings.obs_ids)
             and observations_settings.obs_file is not None
@@ -96,7 +96,7 @@ class Analysis:
             obs_list = self.datastore.get_observations(observations_settings.obs_ids)
             ids = [obs.obs_id for obs in obs_list]
         else:
-            path = make_path(self.config.observations.obs_file)
+            path = make_path(observations_settings.obs_file)
             ids = list(Table.read(path, format="ascii", data_start=0).columns[0])
 
         if observations_settings.obs_cone.lon is not None:
@@ -111,9 +111,9 @@ class Analysis:
             selected_cone = self.datastore.obs_table.select_observations(cone)
             ids = list(set(ids) & set(selected_cone["OBS_ID"].tolist()))
         self.observations = self.datastore.get_observations(ids, skip_missing=True)
-        if self.config.observations.obs_time.start is not None:
-            start = self.config.observations.obs_time.start
-            stop = self.config.observations.obs_time.stop
+        if observations_settings.obs_time.start is not None:
+            start = observations_settings.obs_time.start
+            stop = observations_settings.obs_time.stop
             self.observations = self.observations.select_time([(start, stop)])
         log.info(f"Number of selected observations: {len(self.observations)}")
         for obs in self.observations:
@@ -121,15 +121,14 @@ class Analysis:
 
     def get_datasets(self):
         """Produce reduced datasets."""
+        datasets_settings = self.config.datasets
         if not self.observations or len(self.observations) == 0:
             raise RuntimeError("No observations have been selected.")
 
-        if self.config.datasets.type == "1d":
+        if datasets_settings.type == "1d":
             self._spectrum_extraction()
-        elif self.config.datasets.type == "3d":
+        else:  # 3d
             self._map_making()
-        else:
-            ValueError(f"Invalid dataset type: {self.config.datasets.type}")
 
     def set_models(self, models):
         """Set models on datasets.
@@ -144,16 +143,17 @@ class Analysis:
 
         log.info(f"Reading model.")
         if isinstance(models, str):
-            # FIXME: Models should offer a method to create from YAML str
-            models = yaml.safe_load(models)
-            self.models = Models(dict_to_models(models))
+            self.models = Models.from_yaml(models)
         elif isinstance(models, Models):
             self.models = models
         else:
             raise TypeError(f"Invalid type: {models!r}")
 
         for dataset in self.datasets:
-            dataset.models = self.models
+            if dataset.models is not None:
+                dataset.models.extend(self.models)
+            else:
+                dataset.models = self.models
 
         log.info(self.models)
 
@@ -173,10 +173,7 @@ class Analysis:
             if fit_settings.fit_range:
                 e_min = fit_settings.fit_range.min
                 e_max = fit_settings.fit_range.max
-                if isinstance(dataset, MapDataset):
-                    dataset.mask_fit = dataset.counts.geom.energy_mask(e_min, e_max)
-                else:
-                    dataset.mask_fit = dataset.counts.energy_mask(e_min, e_max)
+                dataset.mask_fit = dataset.counts.geom.energy_mask(e_min, e_max)
 
         log.info("Fitting datasets.")
         self.fit = Fit(self.datasets)
@@ -192,12 +189,9 @@ class Analysis:
         log.info("Calculating flux points.")
         e_edges = self._make_energy_axis(fp_settings.energy).edges
         flux_point_estimator = FluxPointsEstimator(
-            e_edges=e_edges,
-            datasets=self.datasets,
-            source=fp_settings.source,
-            **fp_settings.params,
+            e_edges=e_edges, source=fp_settings.source, **fp_settings.parameters,
         )
-        fp = flux_point_estimator.run()
+        fp = flux_point_estimator.run(datasets=self.datasets)
         fp.table["is_ul"] = fp.table["ts"] < 4
         self.flux_points = FluxPointsDataset(
             data=fp, models=self.models[fp_settings.source]
@@ -232,34 +226,62 @@ class Analysis:
 
     def _map_making(self):
         """Make maps and datasets for 3d analysis."""
+        datasets_settings = self.config.datasets
         log.info("Creating geometry.")
-
         geom = self._create_geometry()
-        geom_settings = self.config.datasets.geom
+        geom_settings = datasets_settings.geom
         geom_irf = dict(energy_axis_true=None, binsz_irf=None)
         if geom_settings.axes.energy_true.min is not None:
             geom_irf["energy_axis_true"] = self._make_energy_axis(
-                geom_settings.axes.energy_true
+                geom_settings.axes.energy_true, name="energy_true"
             )
         geom_irf["binsz_irf"] = geom_settings.wcs.binsize_irf.to("deg").value
         offset_max = geom_settings.selection.offset_max
         log.info("Creating datasets.")
 
-        maker = MapDatasetMaker(selection=self.config.datasets.map_selection)
+        maker = MapDatasetMaker(selection=datasets_settings.map_selection)
 
-        safe_mask_selection = self.config.datasets.safe_mask.methods
-        safe_mask_settings = self.config.datasets.safe_mask.settings
+        safe_mask_selection = datasets_settings.safe_mask.methods
+        safe_mask_settings = datasets_settings.safe_mask.parameters
         maker_safe_mask = SafeMaskMaker(
             methods=safe_mask_selection, **safe_mask_settings
         )
+
+        bkg_maker_config = {}
+        if datasets_settings.background.exclusion:
+            exclusion_region = Map.read(datasets_settings.background.exclusion)
+            bkg_maker_config["exclusion_mask"] = exclusion_region
+        bkg_maker_config.update(datasets_settings.background.parameters)
+
+        bkg_method = datasets_settings.background.method
+        if bkg_method == "fov_background":
+            log.debug(f"Creating FoVBackgroundMaker with arguments {bkg_maker_config}")
+            bkg_maker = FoVBackgroundMaker(**bkg_maker_config)
+        elif bkg_method == "ring":
+            bkg_maker = RingBackgroundMaker(**bkg_maker_config)
+            log.debug(f"Creating RingBackgroundMaker with arguments {bkg_maker_config}")
+            if datasets_settings.geom.axes.energy.nbins > 1:
+                raise ValueError(
+                    "You need to define a single-bin energy geometry for your dataset."
+                )
+        else:
+            bkg_maker = None
+            log.warning(
+                f"No background maker set for 3d analysis. Check configuration."
+            )
+
         stacked = MapDataset.create(geom=geom, name="stacked", **geom_irf)
 
-        if self.config.datasets.stack:
+        if datasets_settings.stack:
             for obs in self.observations:
                 log.info(f"Processing observation {obs.obs_id}")
                 cutout = stacked.cutout(obs.pointing_radec, width=2 * offset_max)
                 dataset = maker.run(cutout, obs)
                 dataset = maker_safe_mask.run(dataset, obs)
+                if bkg_maker is not None:
+                    dataset = bkg_maker.run(dataset)
+                if bkg_method == "ring":
+                    dataset.models = Models([BackgroundModel(dataset.background)])
                 log.debug(dataset)
                 stacked.stack(dataset)
             datasets = [stacked]
@@ -270,6 +292,8 @@ class Analysis:
                 cutout = stacked.cutout(obs.pointing_radec, width=2 * offset_max)
                 dataset = maker.run(cutout, obs)
                 dataset = maker_safe_mask.run(dataset, obs)
+                if bkg_maker is not None:
+                    dataset = bkg_maker.run(dataset)
                 log.debug(dataset)
                 datasets.append(dataset)
         self.datasets = Datasets(datasets)
@@ -292,19 +316,33 @@ class Analysis:
 
         maker_config["selection"] = ["counts", "aeff", "edisp"]
         dataset_maker = SpectrumDatasetMaker(**maker_config)
+
         bkg_maker_config = {}
         if datasets_settings.background.exclusion:
             exclusion_region = Map.read(datasets_settings.background.exclusion)
             bkg_maker_config["exclusion_mask"] = exclusion_region
-        bkg_maker = ReflectedRegionsBackgroundMaker(**bkg_maker_config)
+        bkg_maker_config.update(datasets_settings.background.parameters)
+        bkg_method = datasets_settings.background.method
+        if bkg_method == "reflected":
+            bkg_maker = ReflectedRegionsBackgroundMaker(**bkg_maker_config)
+            log.debug(
+                f"Creating ReflectedRegionsBackgroundMaker with arguments {bkg_maker_config}"
+            )
+        else:
+            bkg_maker = None
+            log.warning(
+                f"No background maker set for 1d analysis. Check configuration."
+            )
 
-        safe_mask_selection = self.config.datasets.safe_mask.methods
-        safe_mask_settings = self.config.datasets.safe_mask.settings
+        safe_mask_selection = datasets_settings.safe_mask.methods
+        safe_mask_settings = datasets_settings.safe_mask.parameters
         safe_mask_maker = SafeMaskMaker(
             methods=safe_mask_selection, **safe_mask_settings
         )
 
-        e_true = self._make_energy_axis(datasets_settings.geom.axes.energy_true).edges
+        e_true = self._make_energy_axis(
+            datasets_settings.geom.axes.energy_true, name="energy_true"
+        ).edges
 
         reference = SpectrumDataset.create(
             e_reco=e_reco, e_true=e_true, region=on_region
@@ -314,26 +352,27 @@ class Analysis:
         for obs in self.observations:
             log.info(f"Processing observation {obs.obs_id}")
             dataset = dataset_maker.run(reference.copy(), obs)
-            dataset = bkg_maker.run(dataset, obs)
-            if dataset.counts_off is None:
-                log.info(
-                    f"No OFF region found for observation {obs.obs_id}. Discarding."
-                )
-                continue
+            if bkg_maker is not None:
+                dataset = bkg_maker.run(dataset, obs)
+                if dataset.counts_off is None:
+                    log.info(
+                        f"No OFF region found for observation {obs.obs_id}. Discarding."
+                    )
+                    continue
             dataset = safe_mask_maker.run(dataset, obs)
             log.debug(dataset)
             datasets.append(dataset)
 
         self.datasets = Datasets(datasets)
 
-        if self.config.datasets.stack:
+        if datasets_settings.stack:
             stacked = self.datasets.stack_reduce(name="stacked")
             self.datasets = Datasets([stacked])
 
     @staticmethod
-    def _make_energy_axis(axis):
+    def _make_energy_axis(axis, name="energy"):
         return MapAxis.from_bounds(
-            name="energy",
+            name=name,
             lo_bnd=axis.min.value,
             hi_bnd=axis.max.to_value(axis.min.unit),
             nbin=axis.nbins,
