@@ -5,17 +5,20 @@ from numpy.testing import assert_allclose
 import astropy.units as u
 from astropy.coordinates import SkyCoord
 from regions import CircleSkyRegion
+from pydantic.error_wrappers import ValidationError
 from gammapy.analysis import Analysis, AnalysisConfig
-from gammapy.maps import Map
+from gammapy.datasets import MapDataset, SpectrumDatasetOnOff
+from gammapy.maps import Map, WcsNDMap
 from gammapy.modeling.models import Models
 from gammapy.utils.testing import requires_data, requires_dependency
 
 CONFIG_PATH = Path(__file__).resolve().parent / ".." / "config"
 MODEL_FILE = CONFIG_PATH / "model.yaml"
+MODEL_FILE_1D = CONFIG_PATH / "model-1d.yaml"
 
 
 def get_example_config(which):
-    """Example config: which can be "1d" or "3d"."""
+    """Example config: which can be 1d or 3d."""
     return AnalysisConfig.read(CONFIG_PATH / f"example-{which}.yaml")
 
 
@@ -146,7 +149,7 @@ def test_analysis_1d():
         on_region: {frame: icrs, lon: 83.633 deg, lat: 22.014 deg, radius: 0.11 deg}
         safe_mask:
             methods: [aeff-default, edisp-bias]
-            settings: {bias_percent: 10.0}
+            parameters: {bias_percent: 10.0}
         containment_correction: false
     flux_points:
         energy: {min: 1 TeV, max: 50 TeV, nbins: 4}
@@ -156,7 +159,7 @@ def test_analysis_1d():
     analysis.update_config(cfg)
     analysis.get_observations()
     analysis.get_datasets()
-    analysis.read_models(MODEL_FILE)
+    analysis.read_models(MODEL_FILE_1D)
     analysis.run_fit()
     analysis.get_flux_points()
 
@@ -166,7 +169,7 @@ def test_analysis_1d():
     assert dnde.unit == "cm-2 s-1 TeV-1"
 
     assert_allclose(dnde[0].value, 8.116854e-12, rtol=1e-2)
-    assert_allclose(dnde[-1].value, 5.540578e-21, rtol=1e-2)
+    assert_allclose(dnde[2].value, 3.547128e-14, rtol=1e-2)
 
 
 @requires_data()
@@ -204,19 +207,31 @@ def test_geom_analysis_1d():
 def test_exclusion_region(tmp_path):
     config = get_example_config("1d")
     analysis = Analysis(config)
-
     exclusion_region = CircleSkyRegion(center=SkyCoord("85d 23d"), radius=1 * u.deg)
     exclusion_mask = Map.create(npix=(150, 150), binsz=0.05, skydir=SkyCoord("83d 22d"))
     mask = exclusion_mask.geom.region_mask([exclusion_region], inside=False)
     exclusion_mask.data = mask.astype(int)
     filename = tmp_path / "exclusion.fits"
     exclusion_mask.write(filename)
+    config.datasets.background.method = "reflected"
     config.datasets.background.exclusion = filename
-
     analysis.get_observations()
     analysis.get_datasets()
     assert len(analysis.datasets) == 2
 
+    config = get_example_config("3d")
+    analysis = Analysis(config)
+    analysis.get_observations()
+    analysis.get_datasets()
+    geom = analysis.datasets[0]._geom
+    exclusion = WcsNDMap.from_geom(geom)
+    exclusion.data = geom.region_mask([exclusion_region], inside=False).astype(int)
+    filename = tmp_path / "exclusion3d.fits"
+    exclusion.write(filename)
+    config.datasets.background.exclusion = filename
+    analysis.get_datasets()
+    assert len(analysis.datasets) == 1
+
 
 @requires_dependency("iminuit")
 @requires_data()
@@ -226,6 +241,8 @@ def test_analysis_1d_stacked():
         geom:
             axes:
                 energy_true: {min: 0.03 TeV, max: 100 TeV, nbins: 50}
+        background:
+            method: reflected
     """
 
     config = get_example_config("1d")
@@ -234,7 +251,7 @@ def test_analysis_1d_stacked():
     analysis.config.datasets.stack = True
     analysis.get_observations()
     analysis.get_datasets()
-    analysis.read_models(MODEL_FILE)
+    analysis.read_models(MODEL_FILE_1D)
     analysis.run_fit()
 
     assert len(analysis.datasets) == 1
@@ -245,6 +262,48 @@ def test_analysis_1d_stacked():
     assert_allclose(pars["amplitude"].value, 5.496388e-11, rtol=1e-2)
 
 
+@requires_data()
+def test_analysis_ring_background():
+    config = get_example_config("3d")
+    config.datasets.background.method = "ring"
+    config.datasets.background.parameters = {"r_in": "0.7 deg", "width": "0.7 deg"}
+    config.datasets.geom.axes.energy.nbins = 1
+    analysis = Analysis(config)
+    analysis.get_observations()
+    analysis.get_datasets()
+    assert isinstance(analysis.datasets[0], MapDataset)
+    assert_allclose(
+        analysis.datasets[0].background_model.map.data[0, 10, 10], 0.091552, rtol=1e-5
+    )
+
+
+@requires_data()
+def test_analysis_ring_3d():
+    config = get_example_config("3d")
+    config.datasets.background.method = "ring"
+    config.datasets.background.parameters = {"r_in": "0.7 deg", "width": "0.7 deg"}
+    analysis = Analysis(config)
+    analysis.get_observations()
+    with pytest.raises(ValueError):
+        analysis.get_datasets()
+
+
+@requires_data()
+def test_analysis_no_bkg():
+    config = get_example_config("1d")
+    analysis = Analysis(config)
+    analysis.get_observations()
+    analysis.get_datasets()
+    assert isinstance(analysis.datasets[0], SpectrumDatasetOnOff) is False
+
+    config = get_example_config("3d")
+    config.datasets.background.method = None
+    analysis = Analysis(config)
+    analysis.get_observations()
+    analysis.get_datasets()
+    assert isinstance(analysis.datasets[0], MapDataset) is True
+
+
 @requires_dependency("iminuit")
 @requires_data()
 def test_analysis_3d():
@@ -264,10 +323,10 @@ def test_analysis_3d():
     assert len(analysis.flux_points.data.table) == 2
     dnde = analysis.flux_points.data.table["dnde"].quantity
 
-    assert_allclose(dnde[0].value, 1.408433e-11, rtol=1e-2)
-    assert_allclose(dnde[-1].value, 3.948827e-13, rtol=1e-2)
-    assert_allclose(res["index"].value, 2.921873, rtol=1e-2)
-    assert_allclose(res["tilt"].value, -0.133544, rtol=1e-2)
+    assert_allclose(dnde[0].value, 1.340073e-11, rtol=1e-2)
+    assert_allclose(dnde[-1].value, 3.483509e-13, rtol=1e-2)
+    assert_allclose(res["index"].value, 3.097613, rtol=1e-2)
+    assert_allclose(res["tilt"].value, -0.207792, rtol=1e-2)
 
 
 @requires_data()
@@ -278,6 +337,11 @@ def test_analysis_3d_joint_datasets():
     analysis.get_observations()
     analysis.get_datasets()
     assert len(analysis.datasets) == 2
+    assert_allclose(analysis.datasets[0].background_model.norm.value, 1.031743694988066)
+    assert_allclose(analysis.datasets[0].background_model.tilt.value, 0.0)
+    assert_allclose(
+        analysis.datasets[1].background_model.norm.value, 0.9776349021876344
+    )
 
 
 @requires_dependency("iminuit")
@@ -293,3 +357,5 @@ def test_usage_errors():
         analysis.run_fit()
     with pytest.raises(RuntimeError):
         analysis.get_flux_points()
+    with pytest.raises(ValidationError):
+        analysis.config.datasets.type = "None"
