@@ -77,12 +77,6 @@ class SourceCatalog(abc.ABC):
         row by alias names as well.
     """
 
-    @classmethod
-    @abc.abstractmethod
-    def name(cls):
-        """Catalog name (str)."""
-        pass
-
     @classmethod
     @abc.abstractmethod
     def description(cls):
