@@ -7,6 +7,7 @@ import astropy.units as u
 from astropy.table import Column, Table
 from astropy.time import Time
 from astropy.wcs import FITSFixedWarning
+from gammapy.estimators import FluxPoints, LightCurve
 from gammapy.modeling.models import (
     DiskSpatialModel,
     GaussianSpatialModel,
@@ -15,8 +16,6 @@ from gammapy.modeling.models import (
     SkyModel,
     TemplateSpatialModel,
 )
-from gammapy.spectrum import FluxPoints
-from gammapy.time import LightCurve
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.scripts import make_path
 from gammapy.utils.table import table_standardise_units_inplace
@@ -186,7 +185,8 @@ class SourceCatalogObjectFermiBase(SourceCatalogObject, abc.ABC):
         lon_err = semi_minor / scale_1sigma / np.cos(d["DEJ2000"])
 
         if model.tag != "TemplateSpatialModel":
-            model.parameters.set_error(lon_0=lon_err, lat_0=lat_err)
+            model.parameters["lon_0"].error = lon_err
+            model.parameters["lat_0"].error = lat_err
             model.phi_0 = phi_0
 
     def sky_model(self):
@@ -412,7 +412,10 @@ class SourceCatalogObject4FGL(SourceCatalogObjectFermiBase):
             raise ValueError(f"Invalid spec_type: {spec_type!r}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     @property
@@ -674,7 +677,10 @@ class SourceCatalogObject3FGL(SourceCatalogObjectFermiBase):
             raise ValueError(f"Invalid spec_type: {spec_type!r}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     def spatial_model(self):
@@ -901,7 +907,10 @@ class SourceCatalogObject2FHL(SourceCatalogObjectFermiBase):
         }
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     @property
@@ -1071,7 +1080,10 @@ class SourceCatalogObject3FHL(SourceCatalogObjectFermiBase):
             raise ValueError(f"Invalid spec_type: {spec_type!r}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     @property
@@ -1154,7 +1166,7 @@ class SourceCatalog3FGL(SourceCatalog):
     One source is represented by `~gammapy.catalog.SourceCatalogObject3FGL`.
     """
 
-    name = "3fgl"
+    tag = "3fgl"
     description = "LAT 4-year point source catalog"
     source_object_class = SourceCatalogObject3FGL
 
@@ -1196,7 +1208,7 @@ class SourceCatalog4FGL(SourceCatalog):
     One source is represented by `~gammapy.catalog.SourceCatalogObject4FGL`.
     """
 
-    name = "4fgl"
+    tag = "4fgl"
     description = "LAT 8-year point source catalog"
     source_object_class = SourceCatalogObject4FGL
 
@@ -1235,7 +1247,7 @@ class SourceCatalog2FHL(SourceCatalog):
     One source is represented by `~gammapy.catalog.SourceCatalogObject2FHL`.
     """
 
-    name = "2fhl"
+    tag = "2fhl"
     description = "LAT second high-energy source catalog"
     source_object_class = SourceCatalogObject2FHL
 
@@ -1269,7 +1281,7 @@ class SourceCatalog3FHL(SourceCatalog):
     One source is represented by `~gammapy.catalog.SourceCatalogObject3FHL`.
     """
 
-    name = "3fhl"
+    tag = "3fhl"
     description = "LAT third high-energy source catalog"
     source_object_class = SourceCatalogObject3FHL
 
