@@ -7,8 +7,8 @@ import logging
 import numpy as np
 from astropy import units as u
 from astropy.table import Table
+from gammapy.estimators import FluxPoints
 from gammapy.modeling.models import Model, SkyModel
-from gammapy.spectrum import FluxPoints
 from gammapy.utils.scripts import make_path
 from .core import SourceCatalog, SourceCatalogObject
 
@@ -220,7 +220,9 @@ class SourceCatalogObjectGammaCat(SourceCatalogObject):
             raise ValueError(f"Invalid spec_type: {spec_type}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     def spatial_model(self):
@@ -261,7 +263,10 @@ class SourceCatalogObjectGammaCat(SourceCatalogObject):
             raise ValueError(f"Invalid morph_type: {morph_type!r}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     def sky_model(self):
@@ -350,7 +355,7 @@ class SourceCatalogGammaCat(SourceCatalog):
     >>> source.flux_points.plot()
     """
 
-    name = "gamma-cat"
+    tag = "gamma-cat"
     description = "An open catalog of gamma-ray sources"
     source_object_class = SourceCatalogObjectGammaCat
 
