@@ -121,7 +121,10 @@ class SourceCatalogObject2HWC(SourceCatalogObject):
         }
 
         model = Model.create("PowerLawSpectralModel", **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     def spatial_model(self, which="point"):
@@ -146,7 +149,10 @@ class SourceCatalogObject2HWC(SourceCatalogObject):
         }
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     def sky_model(self, which="point"):
@@ -184,7 +190,7 @@ class SourceCatalog2HWC(SourceCatalog):
        On ADS: `2017ApJ...843...40A <https://ui.adsabs.harvard.edu/abs/2017ApJ...843...40A>`__
     """
 
-    name = "2hwc"
+    tag = "2hwc"
     """Catalog name"""
 
     description = "2HWC catalog from the HAWC observatory"
