@@ -5,8 +5,8 @@ import astropy.units as u
 from astropy.coordinates import Angle
 from astropy.modeling.models import Gaussian1D
 from astropy.table import Table
+from gammapy.estimators import FluxPoints
 from gammapy.modeling.models import Model, Models, SkyModel
-from gammapy.spectrum import FluxPoints
 from gammapy.utils.interpolation import ScaledRegularGridInterpolator
 from gammapy.utils.scripts import make_path
 from gammapy.utils.table import table_row_to_dict
@@ -78,7 +78,10 @@ class SourceCatalogObjectHGPSComponent(SourceCatalogObject):
         }
         errs = {"lon_0": d["GLON_Err"], "lat_0": d["GLAT_Err"], "sigma": d["Size_Err"]}
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
 
@@ -463,7 +466,11 @@ class SourceCatalogObjectHGPS(SourceCatalogObject):
             raise ValueError(f"Invalid spec_type: {spec_type}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+        errs["reference"] = 0 * u.TeV
+
+        for name, value in errs.items():
+            model.parameters[name].error = value
+
         return model
 
     def spatial_model(self):
@@ -501,7 +508,8 @@ class SourceCatalogObjectHGPS(SourceCatalogObject):
             raise ValueError(f"Invalid spatial_type: {spatial_type}")
 
         model = Model.create(tag, **pars)
-        model.parameters.set_error(**errs)
+        for name, value in errs.items():
+            model.parameters[name].error = value
         return model
 
     def sky_model(self, which="best"):
@@ -598,7 +606,7 @@ class SourceCatalogHGPS(SourceCatalog):
     >>> cat.gaussian_component(83)
     """
 
-    name = "hgps"
+    tag = "hgps"
     """Source catalog name (str)."""
 
     description = "H.E.S.S. Galactic plane survey (HGPS) source catalog"
