@@ -284,19 +284,24 @@ class EventListBase:
         energy = self.energy
         return MapAxis.from_energy_bounds(energy.min(), energy.max(), 50).edges
 
-    def _counts_spectrum(self, ebounds):
-        from gammapy.spectrum import CountsSpectrum
-
-        if not ebounds:
-            ebounds = self._default_plot_ebounds()
-        spec = CountsSpectrum(energy_lo=ebounds[:-1], energy_hi=ebounds[1:])
-        spec.fill_energy(self.energy)
-        return spec
-
     def plot_energy(self, ax=None, ebounds=None, **kwargs):
         """Plot counts as a function of energy."""
-        spec = self._counts_spectrum(ebounds)
-        ax = spec.plot(ax=ax, **kwargs)
+        import matplotlib.pyplot as plt
+
+        ax = plt.gca() if ax is None else ax
+
+        kwargs.setdefault("log", True)
+        kwargs.setdefault("histtype", "step")
+
+        if ebounds is None:
+            ebounds = self._default_plot_ebounds()
+
+        unit = ebounds.unit
+
+        ax.hist(self.energy.to_value(unit), bins=ebounds.value, **kwargs)
+        ax.loglog()
+        ax.set_xlabel(f"Energy ({unit})")
+        ax.set_ylabel("Counts")
         return ax
 
     def plot_time(self, ax=None):
@@ -411,7 +416,8 @@ class EventListBase:
         ax = plt.gca() if ax is None else ax
 
         energy_bounds = self._default_plot_ebounds().to_value("TeV")
-        offset_bounds = np.linspace(0, 4, 30)
+        offsetangle = self.pointing_radec.separation(self.radec).max().to("deg").value
+        offset_bounds = np.linspace(0, offsetangle, 30)
 
         counts = np.histogram2d(
             x=self.energy.value,
@@ -592,22 +598,23 @@ class EventList(EventListBase):
         import matplotlib.pyplot as plt
 
         fig, axes = plt.subplots(nrows=2, ncols=3, figsize=(12, 8))
-
         self.plot_energy(ax=axes[0, 0])
-        bins = np.linspace(start=0, stop=4 ** 2, num=30)
+
+        off_max = self.pointing_radec.separation(self.radec).max().deg
+        bins = np.linspace(start=0, stop=off_max ** 2, num=30)
         self.plot_offset2_distribution(ax=axes[0, 1], bins=bins)
+
         self.plot_time(ax=axes[0, 2])
 
         axes[1, 0].axis("off")
         m = self._counts_image()
         ax = plt.subplot(2, 3, 4, projection=m.geom.wcs)
-        m.plot(ax=ax, stretch="sqrt")
+        m.plot(ax=ax, stretch="linear")
 
         self.plot_energy_offset(ax=axes[1, 1])
 
         self._plot_text_summary(ax=axes[1, 2])
-
-        plt.tight_layout()
+        plt.subplots_adjust(hspace=0.3, wspace=0.2)
 
     def _plot_text_summary(self, ax):
         ax.axis("off")
@@ -615,16 +622,17 @@ class EventList(EventListBase):
         ax.text(0, 1, txt, fontsize=12, verticalalignment="top")
 
     def _counts_image(self):
+        width = self.galactic.b.max().deg - self.galactic.b.min().deg
         opts = {
-            "width": (7, 7),
-            "binsz": 0.1,
+            "width": (width, width),
+            "binsz": 0.05,
             "proj": "TAN",
             "frame": "galactic",
             "skydir": self.pointing_radec,
         }
         m = WcsNDMap.create(**opts)
         m.fill_by_coord(self.radec)
-        m = m.smooth(width=1)
+        m = m.smooth(width=0.5)
         return m
 
     def plot_image(self):
