@@ -1,9 +1,14 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import numpy as np
-from astropy.units import Quantity
 from astropy.table import Table, vstack
-from ..utils.time import time_ref_from_dict, time_relative_to_ref
-from ..utils.scripts import make_path
+from astropy.time import Time
+from astropy.units import Quantity
+from gammapy.utils.scripts import make_path
+from gammapy.utils.time import (
+    time_ref_from_dict,
+    time_ref_to_dict,
+    time_relative_to_ref,
+)
 
 __all__ = ["GTI"]
 
@@ -33,9 +38,9 @@ class GTI:
     - Number of GTIs: 1
     - Duration: 1687.0 s
     - Start: 53343.92234009259 MET
-    - Start: 2004-12-04T22:08:10.184(TT)
+    - Start: 2004-12-04T22:08:10.184 (time standard: TT)
     - Stop: 53343.94186555556 MET
-    - Stop: 2004-12-04T22:36:17.184(TT)
+    - Stop: 2004-12-04T22:36:17.184 (time standard: TT)
 
     Load GTIs for a Fermi-LAT event list:
 
@@ -45,9 +50,9 @@ class GTI:
     - Number of GTIs: 39042
     - Duration: 183139597.9032163 s
     - Start: 54682.65603794185 MET
-    - Start: 2008-08-04T15:44:41.678(TT)
+    - Start: 2008-08-04T15:44:41.678 (time standard: TT)
     - Stop: 57236.96833546296 MET
-    - Stop: 2015-08-02T23:14:24.184(TT)
+    - Stop: 2015-08-02T23:14:24.184 (time standard: TT)
     """
 
     def __init__(self, table):
@@ -57,28 +62,54 @@ class GTI:
         return self.__class__(self.table)
 
     @classmethod
-    def read(cls, filename, **kwargs):
+    def create(cls, start, stop, reference_time="2000-01-01"):
+        """Creates a GTI table from start and stop times.
+
+        Parameters
+        ----------
+        start : `~astropy.units.Quantity`
+            start times w.r.t. reference time
+        stop : `~astropy.units.Quantity`
+            stop times w.r.t. reference time
+        reference_time : `~astropy.time.Time`
+            the reference time to use in GTI definition
+        """
+        start = np.atleast_1d(Quantity(start))
+        stop = np.atleast_1d(Quantity(stop))
+        reference_time = Time(reference_time)
+        meta = time_ref_to_dict(reference_time)
+        table = Table({"START": start.to("s"), "STOP": stop.to("s")}, meta=meta)
+        return cls(table)
+
+    @classmethod
+    def read(cls, filename, hdu="GTI"):
         """Read from FITS file.
 
         Parameters
         ----------
         filename : `pathlib.Path`, str
             Filename
+        hdu : str
+            hdu name. Default GTI.
         """
         filename = make_path(filename)
-        kwargs.setdefault("hdu", "GTI")
-        table = Table.read(str(filename), **kwargs)
-        return cls(table=table)
+        table = Table.read(filename, hdu=hdu)
+        return cls(table)
+
+    def write(self, filename, **kwargs):
+        """Write to file."""
+        self.table.write(make_path(filename), **kwargs)
 
     def __str__(self):
-        ss = "GTI info:\n"
-        ss += "- Number of GTIs: {}\n".format(len(self.table))
-        ss += "- Duration: {}\n".format(self.time_sum)
-        ss += "- Start: {} MET\n".format(self.time_start[0])
-        ss += "- Start: {}\n".format(self.time_start[0].fits)
-        ss += "- Stop: {} MET\n".format(self.time_stop[-1])
-        ss += "- Stop: {}\n".format(self.time_stop[-1].fits)
-        return ss
+        return (
+            "GTI info:\n"
+            f"- Number of GTIs: {len(self.table)}\n"
+            f"- Duration: {self.time_sum}\n"
+            f"- Start: {self.time_start[0]} MET\n"
+            f"- Start: {self.time_start[0].fits} (time standard: {self.time_start[-1].scale.upper()})\n"
+            f"- Stop: {self.time_stop[-1]} MET\n"
+            f"- Stop: {self.time_stop[-1].fits} (time standard: {self.time_stop[-1].scale.upper()})\n"
+        )
 
     @property
     def time_delta(self):
