@@ -1,13 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from scipy.interpolate import interp1d
-from astropy.version import version as astropy_version
-from astropy.utils import lazyproperty
-from astropy.units import Quantity
+import scipy.interpolate
+from astropy.coordinates import AltAz, CartesianRepresentation, SkyCoord
 from astropy.table import Table
-from astropy.coordinates import SkyCoord, AltAz, CartesianRepresentation
-from ..utils.scripts import make_path
-from ..utils.time import time_ref_from_dict
-from ..utils.fits import earth_location_from_dict
+from astropy.units import Quantity
+from astropy.utils import lazyproperty
+from gammapy.utils.fits import earth_location_from_dict
+from gammapy.utils.scripts import make_path
+from gammapy.utils.time import time_ref_from_dict
 
 __all__ = ["FixedPointingInfo", "PointingInfo"]
 
@@ -25,9 +24,13 @@ class FixedPointingInfo:
     Examples
     --------
     >>> from gammapy.data import PointingInfo
-    >>> path = '$GAMMAPY_DATA/tests/hess_event_list.fits'
+    >>> path = '$GAMMAPY_DATA/tests/pointing_table.fits.gz'
     >>> pointing_info = PointingInfo.read(path)
     >>> print(pointing_info)
+
+    Note: In order to reproduce the example you need the tests datasets folder.
+    You may download it with the command
+    ``gammapy download datasets --tests --out $GAMMAPY_DATA``
     """
 
     def __init__(self, meta):
@@ -50,7 +53,7 @@ class FixedPointingInfo:
             Pointing info object
         """
         filename = make_path(filename)
-        table = Table.read(str(filename), hdu=hdu)
+        table = Table.read(filename, hdu=hdu)
         return cls(meta=table.meta)
 
     @lazyproperty
@@ -119,8 +122,12 @@ class PointingInfo:
     Examples
     --------
     >>> from gammapy.data import PointingInfo
-    >>> pointing_info = PointingInfo.read('$GAMMAPY_DATA/tests/hess_event_list.fits')
+    >>> pointing_info = PointingInfo.read('$GAMMAPY_DATA/tests/pointing_table.fits.gz')
     >>> print(pointing_info)
+
+    Note: In order to reproduce the example you need the tests datasets folder.
+    You may download it with the command
+    ``gammapy download datasets --tests --out $GAMMAPY_DATA``
     """
 
     def __init__(self, table):
@@ -143,21 +150,21 @@ class PointingInfo:
             Pointing info object
         """
         filename = make_path(filename)
-        table = Table.read(str(filename), hdu=hdu)
+        table = Table.read(filename, hdu=hdu)
         return cls(table=table)
 
     def __str__(self):
         ss = "Pointing info:\n\n"
-        ss += "Location:     {}\n".format(self.location.geodetic)
+        ss += f"Location:     {self.location.geodetic}\n"
         m = self.table.meta
         ss += "MJDREFI, MJDREFF, TIMESYS = {}\n".format(
             (m["MJDREFI"], m["MJDREFF"], m["TIMESYS"])
         )
-        ss += "Time ref:     {}\n".format(self.time_ref.fits)
-        ss += "Time ref:     {} MJD (TT)\n".format(self.time_ref.mjd)
+        ss += f"Time ref:     {self.time_ref.fits}\n"
+        ss += f"Time ref:     {self.time_ref.mjd} MJD (TT)\n"
         sec = self.duration.to("second").value
         hour = self.duration.to("hour").value
-        ss += "Duration:     {} sec = {} hours\n".format(sec, hour)
+        ss += f"Duration:     {sec} sec = {hour} hours\n"
         ss += "Table length: {}\n".format(len(self.table))
 
         ss += "\nSTART:\n" + self._str_for_index(0) + "\n"
@@ -227,17 +234,11 @@ class PointingInfo:
         t_new = time.mjd
         t = self.time.mjd
         xyz = self.altaz.cartesian
-        x_new = interp1d(t, xyz.x)(t_new)
-        y_new = interp1d(t, xyz.y)(t_new)
-        z_new = interp1d(t, xyz.z)(t_new)
+        x_new = scipy.interpolate.interp1d(t, xyz.x)(t_new)
+        y_new = scipy.interpolate.interp1d(t, xyz.y)(t_new)
+        z_new = scipy.interpolate.interp1d(t, xyz.z)(t_new)
         xyz_new = CartesianRepresentation(x_new, y_new, z_new)
         altaz_frame = AltAz(obstime=time, location=self.location)
-
-        # FIXME: an API change in Astropy in 3.1 broke this
-        # See https://github.com/gammapy/gammapy/pull/1906
-        if astropy_version >= "3.1":
-            kwargs = {"representation_type": "unitspherical"}
-        else:
-            kwargs = {"representation": "unitspherical"}
-
-        return SkyCoord(xyz_new, frame=altaz_frame, unit="deg", **kwargs)
+        return SkyCoord(
+            xyz_new, frame=altaz_frame, unit="deg", representation_type="unitspherical"
+        )
