@@ -1,13 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import pytest
 import numpy as np
-from astropy.coordinates import SkyCoord, Angle
+from astropy import units as u
+from astropy.coordinates import Angle, SkyCoord
 from astropy.time import Time
 from astropy.units import Quantity
-from astropy import units as u
-from ...utils.regions import SphericalCircleSkyRegion
-from ...data import DataStore, ObservationFilter, EventListBase, GTI
-from ...utils.testing import requires_data, assert_time_allclose
+from gammapy.data import GTI, DataStore, EventListBase, ObservationFilter
+from gammapy.utils.regions import SphericalCircleSkyRegion
+from gammapy.utils.testing import assert_time_allclose, requires_data
 
 
 def test_event_filter_types():
