@@ -1,36 +1,34 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import pytest
 from numpy.testing import assert_allclose
-from astropy.time import Time
 import astropy.units as u
 from astropy.table import Table
-from ...utils.testing import requires_data, assert_time_allclose
-from ...data import GTI
-from ...utils.time import time_ref_to_dict
+from astropy.time import Time
+from gammapy.data import GTI
+from gammapy.utils.testing import assert_time_allclose, requires_data
+from gammapy.utils.time import time_ref_to_dict
 
 
 @requires_data()
 def test_gti_hess():
-    filename = "$GAMMAPY_DATA/tests/unbundled/hess/run_0023037_hard_eventlist.fits.gz"
-    gti = GTI.read(filename)
+    gti = GTI.read("$GAMMAPY_DATA/hess-dl3-dr1/data/hess_dl3_dr1_obs_id_020136.fits.gz")
     assert "GTI" in str(gti)
     assert len(gti.table) == 1
 
     assert gti.time_delta[0].unit == "s"
-    assert_allclose(gti.time_delta[0].value, 1568.00000)
-    assert_allclose(gti.time_sum.value, 1568.00000)
+    assert_allclose(gti.time_delta[0].value, 1682)
+    assert_allclose(gti.time_sum.value, 1682)
 
-    expected = Time(53292.00592592593, format="mjd", scale="tt")
+    expected = Time(53090.123451203704, format="mjd", scale="tt")
     assert_time_allclose(gti.time_start[0], expected)
 
-    expected = Time(53292.02407407408, format="mjd", scale="tt")
+    expected = Time(53090.14291879629, format="mjd", scale="tt")
     assert_time_allclose(gti.time_stop[0], expected)
 
 
 @requires_data()
 def test_gti_fermi():
-    filename = "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz"
-    gti = GTI.read(filename)
+    gti = GTI.read("$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz")
     assert "GTI" in str(gti)
     assert len(gti.table) == 39042
 
@@ -76,8 +74,7 @@ def test_gti_fermi():
     ],
 )
 def test_select_time(time_interval, expected_length, expected_times):
-    filename = "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz"
-    gti = GTI.read(filename)
+    gti = GTI.read("$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz")
 
     gti_selected = gti.select_time(time_interval)
 
@@ -114,3 +111,26 @@ def test_gti_union():
 
     assert_allclose(gti.table["START"], [1, 5])
     assert_allclose(gti.table["STOP"], [4, 8])
+
+
+def test_gti_create():
+    start = u.Quantity([1, 2], "min")
+    stop = u.Quantity([1.5, 2.5], "min")
+    time_ref = Time("2010-01-01 00:00:00.0")
+
+    gti = GTI.create(start, stop, time_ref)
+
+    assert len(gti.table) == 2
+    assert_allclose(gti.time_ref.mjd, time_ref.tt.mjd)
+    assert_allclose(gti.table["START"], start.to_value("s"))
+
+
+def test_gti_write(tmp_path):
+    gti = make_gti({"START": [5, 6, 1, 2], "STOP": [8, 7, 3, 4]})
+
+    gti.write(tmp_path / "tmp.fits")
+    new_gti = GTI.read(tmp_path / "tmp.fits")
+
+    assert_time_allclose(new_gti.time_start, gti.time_start)
+    assert_time_allclose(new_gti.time_stop, gti.time_stop)
+    assert new_gti.table.meta["MJDREFF"] == gti.table.meta["MJDREFF"]
