@@ -1,18 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import numpy as np
-from astropy.units import Quantity
-from astropy.coordinates import Angle, SkyCoord, AltAz
+from astropy.coordinates import AltAz, Angle, SkyCoord
 from astropy.time import Time, TimeDelta
-from ...data import GTI
-from ...utils.testing import (
-    requires_data,
-    assert_time_allclose,
+from astropy.units import Quantity
+from gammapy.data import GTI, observatory_locations
+from gammapy.data.obs_table import ObservationTable, ObservationTableChecker
+from gammapy.utils.random import get_random_state, sample_sphere
+from gammapy.utils.testing import (
     assert_quantity_allclose,
+    assert_time_allclose,
+    requires_data,
 )
-from ...utils.time import time_ref_from_dict, time_relative_to_ref
-from ...utils.random import sample_sphere, get_random_state
-from ..obs_table import ObservationTable, ObservationTableChecker
-from ..observers import observatory_locations
+from gammapy.utils.time import time_ref_from_dict, time_relative_to_ref
 
 
 def make_test_observation_table(
@@ -260,7 +259,7 @@ def test_select_time_box():
     obs_table_time = make_test_observation_table(
         n_obs=10,
         date_range=(datestart, dateend),
-        use_abs_time=True,
+        use_abs_time=False,
         random_state=random_state,
     )
 
@@ -268,9 +267,20 @@ def test_select_time_box():
     value_range = Time(["2012-01-01T01:00:00", "2012-01-01T02:00:00"])
     selection = dict(type="time_box", time_range=value_range)
     selected_obs_table = obs_table_time.select_observations(selection)
-    time_start = selected_obs_table["TSTART"]
-    assert (value_range[0] < time_start).all()
-    assert (time_start < value_range[1]).all()
+    time_start = selected_obs_table.time_start
+    time_stop = selected_obs_table.time_stop
+
+    assert (value_range[0] < time_start).all() & (time_stop < value_range[1]).all()
+
+    # Test selection with partial overlap of observations and value_range
+    selection_partial = dict(
+        type="time_box", time_range=value_range, partial_overlap=True
+    )
+    selected_obs_table = obs_table_time.select_observations(selection_partial)
+    time_start = selected_obs_table.time_start
+    time_stop = selected_obs_table.time_stop
+
+    assert (value_range[1] > time_start).all() & (time_stop > value_range[0]).all()
 
 
 def test_select_sky_regions():
@@ -288,10 +298,14 @@ def test_select_sky_regions():
     obs_table = obs_table.select_observations(selection)
     assert len(obs_table) == 32
 
+    selection = dict(
+        type="sky_circle", frame="galactic", lon="0 deg", lat="0 deg", radius="50 deg"
+    )
+    obs_table = obs_table.select_observations(selection)
+    assert len(obs_table) == 30
+
 
 def test_create_gti():
-    """Test the `~gammapy.data.ObservationTable.create_gti()` method.
-    """
     date_start = Time("2012-01-01T00:30:00")
     date_end = Time("2012-01-01T02:30:00")
     random_state = np.random.RandomState(seed=0)
@@ -305,7 +319,7 @@ def test_create_gti():
     time_start = met_ref + Quantity(obs_table[0]["TSTART"].astype("float64"), "second")
     time_stop = met_ref + Quantity(obs_table[0]["TSTOP"].astype("float64"), "second")
 
-    assert type(gti) == GTI
+    assert isinstance(gti, GTI)
     assert_time_allclose(gti.time_start, time_start)
     assert_time_allclose(gti.time_stop, time_stop)
     assert_quantity_allclose(
