@@ -3,6 +3,8 @@
 Instrument response functions (IRFs).
 """
 from .background import *
+from .edisp_kernel import *
+from .edisp_map import *
 from .effective_area import *
 from .energy_dispersion import *
 from .io import *
@@ -10,5 +12,7 @@ from .irf_reduce import *
 from .irf_stack import *
 from .psf_3d import *
 from .psf_gauss import *
+from .psf_kernel import *
 from .psf_king import *
+from .psf_map import *
 from .psf_table import *
