@@ -3,8 +3,8 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 import astropy.units as u
-from ...utils.testing import requires_data
-from ..background import Background3D, Background2D
+from gammapy.irf import Background2D, Background3D
+from gammapy.utils.testing import mpl_plot_check, requires_data, requires_dependency
 
 
 @pytest.fixture(scope="session")
@@ -53,11 +53,9 @@ def test_background_3d_basics(bkg_3d):
     assert bkg_2d.data.data.shape == (2, 3)
 
 
-def test_background_3d_read_write(tmpdir, bkg_3d):
-    filename = str(tmpdir / "bkg3d.fits")
-    bkg_3d.to_fits().writeto(filename)
-
-    bkg_3d_2 = Background3D.read(filename)
+def test_background_3d_read_write(tmp_path, bkg_3d):
+    bkg_3d.to_fits().writeto(tmp_path / "bkg3d.fits")
+    bkg_3d_2 = Background3D.read(tmp_path / "bkg3d.fits")
 
     axis = bkg_3d_2.data.axis("energy")
     assert axis.nbin == 2
@@ -132,6 +130,12 @@ def test_background_3d_integrate(bkg_3d):
     assert_allclose(rate.to("s-1 sr-1").value, [[99000000.0, 99000000.0]], rtol=1e-5)
 
 
+@requires_dependency("matplotlib")
+def test_plot(bkg_2d):
+    with mpl_plot_check():
+        bkg_2d.peek()
+
+
 @pytest.fixture(scope="session")
 def bkg_2d():
     """A simple Background2D test case"""
@@ -181,11 +185,9 @@ def test_background_2d_evaluate(bkg_2d):
     assert res.shape == (2,)
 
 
-def test_background_2d_read_write(tmpdir, bkg_2d):
-    filename = str(tmpdir / "bkg2d.fits")
-    bkg_2d.to_fits().writeto(filename)
-
-    bkg_2d_2 = Background2D.read(filename)
+def test_background_2d_read_write(tmp_path, bkg_2d):
+    bkg_2d.to_fits().writeto(tmp_path / "tmp.fits")
+    bkg_2d_2 = Background2D.read(tmp_path / "tmp.fits")
 
     axis = bkg_2d_2.data.axis("energy")
     assert axis.nbin == 2
@@ -223,3 +225,18 @@ def test_background_2d_integrate(bkg_2d):
     )
     assert rate.shape == (1, 2)
     assert_allclose(rate.value, [[0, 198]])
+
+
+@requires_dependency("matplotlib")
+def test_plot(bkg_2d):
+    with mpl_plot_check():
+        bkg_2d.plot()
+
+    with mpl_plot_check():
+        bkg_2d.plot_energy_dependence()
+
+    with mpl_plot_check():
+        bkg_2d.plot_offset_dependence()
+
+    with mpl_plot_check():
+        bkg_2d.plot_spectrum()
