@@ -5,9 +5,8 @@ from .geom import *
 from .hpx import *
 from .hpxmap import *
 from .hpxnd import *
-from .image_utils import *
-from .plotting import *
-from .profile import *
+from .region import *
+from .regionnd import *
 from .wcs import *
 from .wcsmap import *
 from .wcsnd import *
