@@ -65,19 +65,17 @@ class Map(abc.ABC):
         return self._data
 
     @data.setter
-    def data(self, val):
-        if np.isscalar(val):
-            val = val * np.ones(self.geom.data_shape)
+    def data(self, value):
+        if np.isscalar(value):
+            value = value * np.ones(self.geom.data_shape)
 
-        if val.shape != self.geom.data_shape:
-            raise ValueError(
-                f"Shape {val.shape!r} does not match map data shape {self.geom.data_shape!r}"
-            )
-
-        if isinstance(val, u.Quantity):
+        if isinstance(value, u.Quantity):
             raise TypeError("Map data must be a Numpy array. Set unit separately")
 
-        self._data = val
+        if not value.shape == self.geom.data_shape:
+            value = value.reshape(self.geom.data_shape)
+
+        self._data = value
 
     @property
     def unit(self):
@@ -121,7 +119,7 @@ class Map(abc.ABC):
         frame : str
             Coordinate system, either Galactic ("galactic") or Equatorial
             ("icrs").
-        map_type : {'wcs', 'wcs-sparse', 'hpx', 'hpx-sparse'}
+        map_type : {'wcs', 'wcs-sparse', 'hpx', 'hpx-sparse', 'region'}
             Map type.  Selects the class that will be used to
             instantiate the map.
         binsz : float or `~numpy.ndarray`
@@ -137,6 +135,8 @@ class Map(abc.ABC):
             Data unit.
         meta : `dict`
             Dictionary to store meta data.
+        region : `~regions.SkyRegion`
+            Sky region used for the region map.
 
         Returns
         -------
@@ -145,12 +145,16 @@ class Map(abc.ABC):
         """
         from .hpxmap import HpxMap
         from .wcsmap import WcsMap
+        from .regionnd import RegionNDMap
 
         map_type = kwargs.setdefault("map_type", "wcs")
         if "wcs" in map_type.lower():
             return WcsMap.create(**kwargs)
         elif "hpx" in map_type.lower():
             return HpxMap.create(**kwargs)
+        elif map_type == "region":
+            _ = kwargs.pop("map_type")
+            return RegionNDMap.create(**kwargs)
         else:
             raise ValueError(f"Unrecognized map type: {map_type!r}")
 
@@ -215,11 +219,14 @@ class Map(abc.ABC):
 
             from .hpx import HpxGeom
             from .wcs import WcsGeom
+            from .region import RegionGeom
 
             if isinstance(geom, HpxGeom):
                 map_type = "hpx"
             elif isinstance(geom, WcsGeom):
                 map_type = "wcs"
+            elif isinstance(geom, RegionGeom):
+                map_type = "region"
             else:
                 raise ValueError("Unrecognized geom type.")
 
@@ -282,6 +289,10 @@ class Map(abc.ABC):
             return HpxNDMap
         elif map_type == "hpx-sparse":
             raise NotImplementedError()
+        elif map_type == "region":
+            from .regionnd import RegionNDMap
+
+            return RegionNDMap
         else:
             raise ValueError(f"Unrecognized map type: {map_type!r}")
 
@@ -920,6 +931,33 @@ class Map(abc.ABC):
             raise ValueError("Can't copy and change geometry of the map.")
         return self._init_copy(**kwargs)
 
+    def apply_edisp(self, edisp):
+        """Apply energy dispersion to map. Requires energy axis.
+
+        Parameters
+        ----------
+        edisp : `gammapy.irf.EDispKernel`
+            Energy dispersion matrix
+
+        Returns
+        -------
+        map : `WcsNDMap`
+            Map with energy dispersion applied.
+        """
+        # TODO: either use sparse matrix mutiplication or something like edisp.is_diagonal
+        if edisp is not None:
+            loc = self.geom.get_axis_index_by_name("energy_true")
+            data = np.rollaxis(self.data, loc, len(self.data.shape))
+            data = np.dot(data, edisp.pdf_matrix)
+            data = np.rollaxis(data, -1, loc)
+            e_reco_axis = edisp.e_reco.copy(name="energy")
+        else:
+            data = self.data
+            e_reco_axis = self.geom.get_axis_by_name("energy_true").copy(name="energy")
+
+        geom_reco = self.geom.to_image().to_cube(axes=[e_reco_axis])
+        return self._init_copy(geom=geom_reco, data=data)
+
     def __repr__(self):
         geom = self.geom.__class__.__name__
         axes = ["skycoord"] if self.geom.is_hpx else ["lon", "lat"]
