@@ -96,7 +96,9 @@ def energy_axis_from_fgst_template(hdu):
 
     nodes = bands[tag].data
 
-    return [MapAxis.from_nodes(nodes=nodes, name="energy", unit="MeV", interp="log")]
+    return [
+        MapAxis.from_nodes(nodes=nodes, name="energy_true", unit="MeV", interp="log")
+    ]
 
 
 def axes_from_bands_hdu(hdu):
@@ -129,7 +131,8 @@ def axes_from_bands_hdu(hdu):
         if colnames[0] == "E_MIN":
             name = "energy"
         else:
-            name = colnames[0].split("_")[0].lower()
+            name = colnames[0].replace("_MIN", "").lower()
+
         interp = bands.meta.get("INTERP{}".format(idx + 1), "lin")
 
         if node_type == "center":
@@ -443,7 +446,9 @@ class MapAxis:
         return cls(nodes, **kwargs)
 
     @classmethod
-    def from_energy_bounds(cls, emin, emax, nbin, unit=None, per_decade=False):
+    def from_energy_bounds(
+        cls, emin, emax, nbin, unit=None, per_decade=False, name=None
+    ):
         """Make an energy axis.
 
         Used frequently also to make energy grids, by making
@@ -459,6 +464,8 @@ class MapAxis:
             Energy unit
         per_decade : bool
             Whether `nbin` is given per decade.
+        energy_true : bool
+            Whether energy is true energy
 
         Returns
         -------
@@ -475,8 +482,11 @@ class MapAxis:
         if per_decade:
             nbin = np.ceil(np.log10(emax / emin).value * nbin)
 
+        if name is None:
+            name = "energy"
+
         return cls.from_bounds(
-            emin.value, emax.value, nbin=nbin, unit=unit, interp="log", name="energy"
+            emin.value, emax.value, nbin=nbin, unit=unit, interp="log", name=name
         )
 
     @classmethod
@@ -1059,6 +1069,10 @@ class Geom(abc.ABC):
     def center_skydir(self):
         pass
 
+    @property
+    def axes_names(self):
+        return [ax.name for ax in self.axes]
+
     @classmethod
     def from_hdulist(cls, hdulist, hdu=None, hdu_bands=None):
         """Load a geometry object from a FITS HDUList.
@@ -1537,21 +1551,25 @@ class Geom(abc.ABC):
     def energy_mask(self, emin=None, emax=None):
         """Create a mask for a given energy range.
 
+        The energy bin must be fully contained to be included in the mask.
+
         Parameters
         ----------
         emin, emax : `~astropy.units.Quantity`
             Energy range
+
+        Returns
+        -------
+        mask : `~numpy.ndarray`
+            Energy mask
         """
         # get energy axes and values
         energy_axis = self.get_axis_by_name("energy")
-        edges = energy_axis.edges
+        edges = energy_axis.edges.reshape((-1, 1, 1))
 
         # set default values
         emin = emin if emin is not None else edges[0]
         emax = emax if emax is not None else edges[-1]
 
-        # create mask
-        coords = self.get_coord()
-        mask = coords["energy"] > emin
-        mask &= coords["energy"] < emax
-        return mask
+        mask = (edges[:-1] >= emin) & (edges[1:] <= emax)
+        return np.broadcast_to(mask, shape=self.data_shape)
