@@ -2,11 +2,11 @@
 import numpy as np
 from astropy.io import fits
 from astropy.units import Quantity
-from ..utils.units import unit_from_fits_image_hdu
+from gammapy.utils.units import unit_from_fits_image_hdu
 from .geom import MapCoord, pix_tuple_to_idx
-from .utils import interp_to_order, INVALID_INDEX
+from .hpx import HPX_FITS_CONVENTIONS, HpxGeom, HpxToWcsMapping, nside_to_order
 from .hpxmap import HpxMap
-from .hpx import HpxGeom, HpxToWcsMapping, nside_to_order
+from .utils import INVALID_INDEX, interp_to_order
 
 __all__ = ["HpxNDMap"]
 
@@ -26,7 +26,7 @@ class HpxNDMap(HpxMap):
     data : `~numpy.ndarray`
         HEALPIX data array.
         If none then an empty array will be allocated.
-    meta : `~collections.OrderedDict`
+    meta : `dict`
         Dictionary to store meta data.
     unit : str or `~astropy.units.Unit`
         The map unit
@@ -65,6 +65,10 @@ class HpxNDMap(HpxMap):
             The BANDS table HDU
         """
         hpx = HpxGeom.from_header(hdu.header, hdu_bands)
+
+        convname = HpxGeom.identify_hpx_convention(hdu.header)
+        hpx_conv = HPX_FITS_CONVENTIONS[convname]
+
         shape = tuple([ax.nbin for ax in hpx.axes[::-1]])
         # shape_data = shape + tuple([np.max(hpx.npix)])
 
@@ -89,7 +93,7 @@ class HpxNDMap(HpxMap):
             map_out.set_by_idx(idx[::-1], vals)
         else:
             for c in colnames:
-                if c.find(hpx.hpx_conv.colstring) == 0:
+                if c.find(hpx_conv.colstring) == 0:
                     cnames.append(c)
             nbin = len(cnames)
             if nbin == 1:
@@ -193,30 +197,6 @@ class HpxNDMap(HpxMap):
         data = np.nansum(self.data, axis=axis)
         return self._init_copy(geom=geom, data=data)
 
-    def _reproject_to_wcs(self, geom, order=1, mode="interp"):
-        from reproject import reproject_from_healpix
-
-        data = np.empty(geom.data_shape)
-        coordsys = "galactic" if geom.coordsys == "GAL" else "icrs"
-
-        for img, idx in self.iter_by_image():
-            # TODO: Create WCS object for image plane if
-            # multi-resolution geom
-            shape_out = geom.get_image_shape(idx)[::-1]
-            vals, footprint = reproject_from_healpix(
-                (img, coordsys),
-                geom.wcs,
-                shape_out=shape_out,
-                nested=self.geom.nest,
-                order=order,
-            )
-            data[idx] = vals
-
-        return self._init_copy(geom=geom, data=data)
-
-    def _reproject_to_hpx(self):
-        raise NotImplementedError("Maybe try using Map.interp_by_coord().")
-
     def pad(self, pad_width, mode="constant", cval=0, order=1):
         geom = self.geom.pad(pad_width)
         map_out = self._init_copy(geom=geom, data=None)
@@ -233,7 +213,7 @@ class HpxNDMap(HpxMap):
             vals = self.interp_by_coord(coords, interp=order)
             map_out.set_by_coord(coords, vals)
         else:
-            raise ValueError("Unrecognized pad mode: {!r}".format(mode))
+            raise ValueError(f"Unrecognized pad mode: {mode!r}")
 
         return map_out
 
@@ -268,13 +248,13 @@ class HpxNDMap(HpxMap):
 
     def interp_by_coord(self, coords, interp=1):
         # inherited docstring
-        coords = MapCoord.create(coords, coordsys=self.geom.coordsys)
+        coords = MapCoord.create(coords, frame=self.geom.frame)
 
         order = interp_to_order(interp)
         if order == 1:
             return self._interp_by_coord(coords, order)
         else:
-            raise ValueError("Invalid interpolation order: {!r}".format(order))
+            raise ValueError(f"Invalid interpolation order: {order!r}")
 
     def interp_by_pix(self, pix, interp=None):
         """Interpolate map values at the given pixel coordinates.
@@ -473,7 +453,7 @@ class HpxNDMap(HpxMap):
         proj="AIT",
         oversample=2,
         width_pix=1000,
-        **kwargs
+        **kwargs,
     ):
         """Quickplot method.
 
@@ -526,7 +506,7 @@ class HpxNDMap(HpxMap):
         elif method == "poly":
             return self._plot_poly(proj=proj, ax=ax)
         else:
-            raise ValueError("Invalid method: {!r}".format(method))
+            raise ValueError(f"Invalid method: {method!r}")
 
     def _plot_poly(self, proj="AIT", step=1, ax=None):
         """Plot the map using a collection of polygons.
@@ -572,7 +552,7 @@ class HpxNDMap(HpxMap):
             lon, lat = np.degrees(x), np.degrees(np.pi / 2.0 - y)
             # Add a small ofset to avoid vertices wrapping to the
             # other size of the projection
-            if get_angle(np.median(lon), wcs_lonlat[0]) > 0:
+            if get_angle(np.median(lon), wcs_lonlat[0].to_value("deg")) > 0:
                 idx = wcs.coord_to_pix((lon - 1e-4, lat))
             else:
                 idx = wcs.coord_to_pix((lon + 1e-4, lat))
