@@ -8,9 +8,8 @@ from astropy.coordinates import SkyCoord
 from astropy.io import fits
 from astropy.table import Table
 from regions import CircleSkyRegion
-from gammapy.cube import PSFKernel
-from gammapy.cube.fit import MapEvaluator
-from gammapy.irf import EnergyDependentMultiGaussPSF
+from gammapy.datasets.map import MapEvaluator
+from gammapy.irf import EnergyDependentMultiGaussPSF, PSFKernel
 from gammapy.maps import Map, MapAxis, MapCoord, WcsGeom, WcsNDMap
 from gammapy.maps.utils import fill_poisson
 from gammapy.modeling.models import (
@@ -476,7 +475,7 @@ def test_convolve_vs_smooth():
 @requires_data()
 def test_convolve_nd():
     energy_axis = MapAxis.from_edges(
-        np.logspace(-1.0, 1.0, 4), unit="TeV", name="energy"
+        np.logspace(-1.0, 1.0, 4), unit="TeV", name="energy_true"
     )
     geom = WcsGeom.create(binsz=0.02 * u.deg, width=4.0 * u.deg, axes=[energy_axis])
     m = Map.from_geom(geom)
@@ -541,16 +540,16 @@ def test_get_spectrum():
     region = CircleSkyRegion(center=center, radius=1 * u.deg)
 
     spec = m.get_spectrum(region=region)
-    assert_allclose(spec.data, [13.0, 13.0, 13.0])
+    assert_allclose(spec.data.squeeze(), [13.0, 13.0, 13.0])
 
     spec = m.get_spectrum(region=region, func=np.mean)
-    assert_allclose(spec.data, [1.0, 1.0, 1.0])
+    assert_allclose(spec.data.squeeze(), [1.0, 1.0, 1.0])
 
 
 def get_npred_map():
     position = SkyCoord(0.0, 0.0, frame="galactic", unit="deg")
     energy_axis = MapAxis.from_bounds(
-        1, 100, nbin=30, unit="TeV", name="energy", interp="log"
+        1, 100, nbin=30, unit="TeV", name="energy_true", interp="log"
     )
 
     exposure = Map.create(
@@ -586,7 +585,7 @@ def test_map_sampling():
     events = Table()
     events["RA_TRUE"] = skycoord.icrs.ra
     events["DEC_TRUE"] = skycoord.icrs.dec
-    events["ENERGY_TRUE"] = coords["energy"]
+    events["ENERGY_TRUE"] = coords["energy_true"]
 
     assert len(events) == 2
     assert_allclose(events["RA_TRUE"].data, [266.307081, 266.442255], rtol=1e-5)
@@ -595,7 +594,7 @@ def test_map_sampling():
 
     assert coords["lon"].unit == "deg"
     assert coords["lat"].unit == "deg"
-    assert coords["energy"].unit == "TeV"
+    assert coords["energy_true"].unit == "TeV"
 
 
 def test_map_interp_one_bin():
