@@ -4,6 +4,24 @@ from astropy.io import fits
 from gammapy.utils.random import get_random_state
 
 
+def coordsys_to_frame(coordsys):
+    if coordsys in ["CEL", "C"]:
+        return "icrs"
+    elif coordsys in ["GAL", "G"]:
+        return "galactic"
+    else:
+        raise ValueError(f"Unknown coordinate system: '{coordsys}'")
+
+
+def frame_to_coordsys(frame):
+    if frame in ["icrs", "fk5", "fk4"]:
+        return "CEL"
+    elif frame in ["galactic"]:
+        return "GAL"
+    else:
+        raise ValueError(f"Unknown coordinate frame '{frame}'")
+
+
 class InvalidValue:
     """Class to define placeholder for invalid array values."""
 
@@ -57,25 +75,6 @@ def fill_poisson(map_in, mu, random_state="random-seed"):
     map_in.fill_by_idx(idx, mu)
 
 
-def swap_byte_order(arr_in):
-    """Swap the byte order of a numpy array to the native one.
-
-    Parameters
-    ----------
-    arr_in : `~numpy.ndarray`
-        Input array.
-
-    Returns
-    -------
-    arr_out : `~numpy.ndarray`
-        Array with native byte order.
-    """
-    if arr_in.dtype.byteorder not in ("=", "|"):
-        return arr_in.byteswap().newbyteorder()
-
-    return arr_in
-
-
 def interp_to_order(interp):
     """Convert interpolation string to order."""
     if isinstance(interp, int):
