@@ -13,6 +13,7 @@ from gammapy.utils.interpolation import ScaledRegularGridInterpolator
 from gammapy.utils.random import InverseCDFSampler, get_random_state
 from gammapy.utils.units import unit_from_fits_image_hdu
 from .geom import MapCoord, pix_tuple_to_idx
+from .regionnd import RegionGeom, RegionNDMap
 from .utils import INVALID_INDEX, interp_to_order
 from .wcsmap import WcsGeom, WcsMap
 
@@ -563,12 +564,10 @@ class WcsNDMap(WcsMap):
 
         Returns
         -------
-        spectrum : `~gammapy.spectrum.CountsSpectrum`
+        spectrum : `~gammapy.maps.RegionNDMap`
             Spectrum in the given region.
         """
-        from gammapy.spectrum import CountsSpectrum
-
-        energy_axis = self.geom.get_axis_by_name("energy")
+        energy_axis = self.geom.axes[0]
 
         if region:
             mask = self.geom.region_mask([region])
@@ -577,13 +576,9 @@ class WcsNDMap(WcsMap):
         else:
             data = func(self.data, axis=(1, 2))
 
-        edges = energy_axis.edges
-        return CountsSpectrum(
-            data=data,
-            energy_lo=edges[:-1],
-            energy_hi=edges[1:],
-            unit=self.unit,
-            region=region,
+        geom = RegionGeom(region=region, axes=[energy_axis])
+        return RegionNDMap(
+            geom=geom, data=data.reshape(geom.data_shape), unit=self.unit
         )
 
     def convolve(self, kernel, use_fft=True, **kwargs):
@@ -609,7 +604,7 @@ class WcsNDMap(WcsMap):
         map : `WcsNDMap`
             Convolved map.
         """
-        from gammapy.cube import PSFKernel
+        from gammapy.irf import PSFKernel
 
         conv_function = scipy.signal.fftconvolve if use_fft else scipy.ndimage.convolve
         convolved_data = np.empty(self.data.shape, dtype=np.float32)
@@ -632,28 +627,6 @@ class WcsNDMap(WcsMap):
 
         return self._init_copy(data=convolved_data)
 
-    def apply_edisp(self, edisp):
-        """Apply energy dispersion to map. Requires energy axis.
-
-        Parameters
-        ----------
-        edisp : `gammapy.irf.EDispKernel`
-            Energy dispersion matrix
-
-        Returns
-        -------
-        map : `WcsNDMap`
-            Map with energy dispersion applied.
-        """
-        loc = self.geom.get_axis_index_by_name("energy")
-        data = np.rollaxis(self.data, loc, len(self.data.shape))
-        data = np.dot(data, edisp.pdf_matrix)
-        data = np.rollaxis(data, -1, loc)
-
-        e_reco_axis = edisp.e_reco.copy(name="energy")
-        geom_reco = self.geom.to_image().to_cube(axes=[e_reco_axis])
-        return self._init_copy(geom=geom_reco, data=data)
-
     def cutout(self, position, width, mode="trim"):
         """
         Create a cutout around a given position.
@@ -715,9 +688,7 @@ class WcsNDMap(WcsMap):
         if weights is not None:
             if not other.geom.to_image() == weights.geom.to_image():
                 raise ValueError("Incompatible spatial geoms between map and weights")
-
             data = data * weights.data[cutout_slices]
-
         self.data[parent_slices] += data
 
     def sample_coord(self, n_events, random_state=0):
