@@ -1,6 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Models and fitting."""
-from .datasets import *
+from .covariance import *
 from .fit import *
 from .parameter import *
 from .sampling import *
