@@ -2,10 +2,10 @@
 import logging
 import numpy as np
 from astropy.utils import lazyproperty
-from .datasets import Datasets
+from .covariance import Covariance
 from .iminuit import confidence_iminuit, covariance_iminuit, mncontour, optimize_iminuit
-from .scipy import confidence_scipy, covariance_scipy, optimize_scipy
-from .sherpa import covariance_sherpa, optimize_sherpa
+from .scipy import confidence_scipy, optimize_scipy
+from .sherpa import optimize_sherpa
 
 __all__ = ["Fit"]
 
@@ -31,8 +31,8 @@ class Registry:
         },
         "covariance": {
             "minuit": covariance_iminuit,
-            "sherpa": covariance_sherpa,
-            "scipy": covariance_scipy,
+            # "sherpa": covariance_sherpa,
+            # "scipy": covariance_scipy,
         },
         "confidence": {
             "minuit": confidence_iminuit,
@@ -46,12 +46,12 @@ class Registry:
         if task not in cls.register:
             raise ValueError(f"Unknown task {task!r}")
 
-        task = cls.register[task]
+        backend_options = cls.register[task]
 
-        if backend not in task:
-            raise ValueError(f"Unknown method {task!r} for task {backend!r}")
+        if backend not in backend_options:
+            raise ValueError(f"Unknown backend {backend!r} for task {task!r}")
 
-        return task[backend]
+        return backend_options[backend]
 
 
 registry = Registry()
@@ -70,18 +70,26 @@ class Fit:
     """
 
     def __init__(self, datasets):
+        from gammapy.datasets import Datasets
+
         self.datasets = Datasets(datasets)
 
     @lazyproperty
     def _parameters(self):
         return self.datasets.parameters
 
-    def run(self, optimize_opts=None, covariance_opts=None):
+    @lazyproperty
+    def _models(self):
+        return self.datasets.models
+
+    def run(self, backend="minuit", optimize_opts=None, covariance_opts=None):
         """
         Run all fitting steps.
 
         Parameters
         ----------
+        backend : str
+            Backend used for fitting, default : minuit
         optimize_opts : dict
             Options passed to `Fit.optimize`.
         covariance_opts : dict
@@ -94,18 +102,16 @@ class Fit:
         """
         if optimize_opts is None:
             optimize_opts = {}
-        optimize_result = self.optimize(**optimize_opts)
+        optimize_result = self.optimize(backend, **optimize_opts)
 
         if covariance_opts is None:
             covariance_opts = {}
 
-        covariance_opts.setdefault("backend", "minuit")
-
-        if covariance_opts["backend"] not in registry.register["covariance"]:
+        if backend not in registry.register["covariance"]:
             log.warning("No covariance estimate - not supported by this backend.")
             return optimize_result
 
-        covariance_result = self.covariance(**covariance_opts)
+        covariance_result = self.covariance(backend, **covariance_opts)
         # TODO: not sure how best to report the results
         # back or how to form the FitResult object.
         optimize_result._success = optimize_result.success and covariance_result.success
@@ -147,7 +153,7 @@ class Fit:
         parameters = self._parameters
 
         # TODO: expose options if / when to scale? On the Fit class?
-        if parameters.covariance is None:
+        if np.all(self._models.covariance.data == 0):
             parameters.autoscale()
 
         compute = registry.get("optimize", backend)
@@ -176,7 +182,7 @@ class Fit:
             **info,
         )
 
-    def covariance(self, backend="minuit"):
+    def covariance(self, backend="minuit", **kwargs):
         """Estimate the covariance matrix.
 
         Assumes that the model parameters are already optimised.
@@ -199,14 +205,19 @@ class Fit:
             if backend == "minuit":
                 method = "hesse"
                 if hasattr(self, "minuit"):
-                    covariance_factors, info = compute(self.minuit)
+                    factor_matrix, info = compute(self.minuit)
                 else:
                     raise RuntimeError("To use minuit, you must first optimize.")
             else:
                 method = ""
-                covariance_factors, info = compute(parameters, self.datasets.stat_sum)
+                factor_matrix, info = compute(
+                    parameters, self.datasets.stat_sum, **kwargs
+                )
 
-        parameters.set_covariance_factors(covariance_factors)
+            covariance = Covariance.from_factor_matrix(
+                parameters=self._models.parameters, matrix=factor_matrix
+            )
+            self._models.covariance = covariance
 
         # TODO: decide what to return, and fill the info correctly!
         return CovarianceResult(
@@ -323,7 +334,9 @@ class Fit:
             if isinstance(bounds, tuple):
                 parmin, parmax = bounds
             else:
-                parerr = parameters.error(parameter)
+                if np.isnan(parameter.error):
+                    raise ValueError("Parameter error is not properly set.")
+                parerr = parameter.error
                 parval = parameter.value
                 parmin, parmax = parval - bounds * parerr, parval + bounds * parerr
 
