@@ -50,9 +50,9 @@ def optimize_iminuit(parameters, function, **kwargs):
     strategy = kwargs.pop("strategy", 1)
     tol = kwargs.pop("tol", 0.1)
     minuit = Minuit(minuit_func.fcn, **kwargs)
-    minuit.migrad(**migrad_opts)
     minuit.tol = tol
-    minuit.set_strategy(strategy)
+    minuit.strategy = strategy
+    minuit.migrad(**migrad_opts)
 
     factors = minuit.args
     info = {
@@ -82,7 +82,7 @@ def confidence_iminuit(minuit, parameters, parameter, sigma, maxcall=0):
     # TODO: this is ugly - design something better for translating to MINUIT parameter names.
     # Maybe a wrapper class MinuitParameters?
     parameter = parameters[parameter]
-    idx = parameters.free_parameters._get_idx(parameter)
+    idx = parameters.free_parameters.index(parameter)
     var = _make_parname(idx, parameter)
 
     message, success = "Minos terminated successfully.", True
@@ -104,11 +104,11 @@ def confidence_iminuit(minuit, parameters, parameter, sigma, maxcall=0):
 
 def mncontour(minuit, parameters, x, y, numpoints, sigma):
     par_x = parameters[x]
-    idx_x = parameters.free_parameters._get_idx(par_x)
+    idx_x = parameters.free_parameters.index(par_x)
     x = _make_parname(idx_x, par_x)
 
     par_y = parameters[y]
-    idx_y = parameters.free_parameters._get_idx(par_y)
+    idx_y = parameters.free_parameters.index(par_y)
     y = _make_parname(idx_y, par_y)
 
     x_info, y_info, contour = minuit.mncontour(x, y, numpoints, sigma)
@@ -163,10 +163,10 @@ def make_minuit_par_kwargs(parameters):
         max_ = None if np.isnan(par.factor_max) else par.factor_max
         kwargs[f"limit_{name}"] = (min_, max_)
 
-        if parameters.covariance is None:
+        if par.error == 0:
             error = 1
         else:
-            error = parameters.error(par) / par.scale
+            error = par.error / par.scale
 
         kwargs[f"error_{name}"] = error
 
