@@ -4,11 +4,14 @@ import copy
 from pathlib import Path
 import numpy as np
 import astropy.units as u
-from gammapy.maps import Map
-from gammapy.modeling import Parameter, Parameters
+from gammapy.maps import Map, MapAxis, RegionGeom, WcsGeom
+from gammapy.modeling import Covariance, Parameter, Parameters
 from gammapy.modeling.parameter import _get_parameters_str
 from gammapy.utils.scripts import make_name, make_path
 from .core import Model, Models
+from .spatial import SpatialModel
+from .spectral import SpectralModel
+from .temporal import TemporalModel
 
 
 class SkyModelBase(Model):
@@ -25,12 +28,12 @@ class SkyModelBase(Model):
     def __radd__(self, model):
         return self.__add__(model)
 
-    def __call__(self, lon, lat, energy):
-        return self.evaluate(lon, lat, energy)
+    def __call__(self, lon, lat, energy, time=None):
+        return self.evaluate(lon, lat, energy, time)
 
-    def evaluate_geom(self, geom):
+    def evaluate_geom(self, geom, gti=None):
         coords = geom.get_coord(frame=self.frame)
-        return self(coords.lon, coords.lat, coords["energy"])
+        return self(coords.lon, coords.lat, coords["energy_true"])
 
 
 class SkyModel(SkyModelBase):
@@ -53,19 +56,58 @@ class SkyModel(SkyModelBase):
     """
 
     tag = "SkyModel"
+    _apply_irf_default = {"exposure": True, "psf": True, "edisp": True}
 
     def __init__(
-        self, spectral_model, spatial_model=None, temporal_model=None, name=None
+        self,
+        spectral_model,
+        spatial_model=None,
+        temporal_model=None,
+        name=None,
+        apply_irf=None,
+        datasets_names=None,
     ):
         self.spatial_model = spatial_model
         self.spectral_model = spectral_model
         self.temporal_model = temporal_model
-        super().__init__()
-        # TODO: this hack is needed for compound models to work
-        self.__dict__.pop("_parameters")
-
         self._name = make_name(name)
 
+        if apply_irf is None:
+            apply_irf = self._apply_irf_default.copy()
+
+        self.apply_irf = apply_irf
+        self.datasets_names = datasets_names
+        super().__init__()
+
+    @property
+    def _models(self):
+        models = self.spectral_model, self.spatial_model, self.temporal_model
+        return [_ for _ in models if _]
+
+    def _check_covariance(self):
+        if not self.parameters == self._covariance.parameters:
+            self._covariance = Covariance.from_stack(
+                [model.covariance for model in self._models],
+            )
+
+    @property
+    def covariance(self):
+        self._check_covariance()
+
+        for model in self._models:
+            self._covariance.set_subcovariance(model.covariance)
+
+        return self._covariance
+
+    @covariance.setter
+    def covariance(self, covariance):
+        self._check_covariance()
+        self._covariance.data = covariance
+
+        for model in self._models:
+            subcovar = self._covariance.get_subcovariance(model.covariance.parameters)
+            model.covariance = subcovar
+
     @property
     def name(self):
         return self._name
@@ -74,10 +116,14 @@ class SkyModel(SkyModelBase):
     def parameters(self):
         parameters = []
 
+        parameters.append(self.spectral_model.parameters)
+
         if self.spatial_model is not None:
             parameters.append(self.spatial_model.parameters)
 
-        parameters.append(self.spectral_model.parameters)
+        if self.temporal_model is not None:
+            parameters.append(self.temporal_model.parameters)
+
         return Parameters.from_stack(parameters)
 
     @property
@@ -87,8 +133,6 @@ class SkyModel(SkyModelBase):
 
     @spatial_model.setter
     def spatial_model(self, model):
-        from .spatial import SpatialModel
-
         if not (model is None or isinstance(model, SpatialModel)):
             raise TypeError(f"Invalid type: {model!r}")
 
@@ -101,10 +145,9 @@ class SkyModel(SkyModelBase):
 
     @spectral_model.setter
     def spectral_model(self, model):
-        from .spectral import SpectralModel
-
         if not (model is None or isinstance(model, SpectralModel)):
             raise TypeError(f"Invalid type: {model!r}")
+
         self._spectral_model = model
 
     @property
@@ -114,10 +157,9 @@ class SkyModel(SkyModelBase):
 
     @temporal_model.setter
     def temporal_model(self, model):
-        from .temporal import TemporalModel
-
         if not (model is None or isinstance(model, TemporalModel)):
             raise TypeError(f"Invalid type: {model!r}")
+
         self._temporal_model = model
 
     @property
@@ -142,7 +184,7 @@ class SkyModel(SkyModelBase):
             f"temporal_model={self.temporal_model!r})"
         )
 
-    def evaluate(self, lon, lat, energy):
+    def evaluate(self, lon, lat, energy, time=None):
         """Evaluate the model at given points.
 
         The model evaluation follows numpy broadcasting rules.
@@ -156,6 +198,8 @@ class SkyModel(SkyModelBase):
             Spatial coordinates
         energy : `~astropy.units.Quantity`
             Energy coordinate
+        time: `~astropy.time.Time`
+            Time co-ordinate
 
         Returns
         -------
@@ -168,18 +212,57 @@ class SkyModel(SkyModelBase):
         if self.spatial_model is not None:
             value = value * self.spatial_model(lon, lat)  # pylint:disable=not-callable
 
+        if (self.temporal_model is not None) and (time is not None):
+            value = value * self.temporal_model(time)
+
         return value
 
-    def evaluate_geom(self, geom):
+    def evaluate_geom(self, geom, gti=None):
         """Evaluate model on `~gammapy.maps.Geom`."""
-        energy = geom.get_axis_by_name("energy").center[:, np.newaxis, np.newaxis]
+        energy = geom.get_axis_by_name("energy_true").center[:, np.newaxis, np.newaxis]
         value = self.spectral_model(energy)
-        # TODO: case with temporal_model is not None
-        if self.spatial_model is not None:
+
+        if self.spatial_model:
             value = value * self.spatial_model.evaluate_geom(geom.to_image())
 
+        if self.temporal_model:
+            integral = self.temporal_model.integral(gti.time_start, gti.time_stop)
+            value = value * np.sum(integral)
+
         return value
 
+    def integrate_geom(self, geom, gti=None):
+        """Integrate model on `~gammapy.maps.Geom`.
+
+        Parameters
+        ----------
+        geom : `Geom`
+            Map geometry
+        gti : `GTI`
+            GIT table
+
+        Returns
+        -------
+        flux : `Map`
+            Predicted flux map
+        """
+        energy = geom.get_axis_by_name("energy_true").edges
+        value = self.spectral_model.integral(
+            energy[:-1], energy[1:], intervals=True
+        ).reshape((-1, 1, 1))
+
+        if self.spatial_model and not isinstance(geom, RegionGeom):
+            # TODO: integrate spatial model over region to correct for
+            #  containment
+            geom_image = geom.to_image()
+            value = value * self.spatial_model.integrate(geom_image).quantity
+
+        if self.temporal_model:
+            integral = self.temporal_model.integral(gti.time_start, gti.time_stop)
+            value = value * np.sum(integral)
+
+        return Map.from_geom(geom=geom, data=value.value, unit=value.unit)
+
     def copy(self, name=None, **kwargs):
         """Copy SkyModel"""
         if self.spatial_model is not None:
@@ -196,6 +279,8 @@ class SkyModel(SkyModelBase):
         kwargs.setdefault("spectral_model", self.spectral_model.copy())
         kwargs.setdefault("spatial_model", spatial_model)
         kwargs.setdefault("temporal_model", temporal_model)
+        kwargs.setdefault("apply_irf", self.apply_irf.copy())
+        kwargs.setdefault("datasets_names", self.datasets_names)
 
         return self.__class__(**kwargs)
 
@@ -212,6 +297,12 @@ class SkyModel(SkyModelBase):
         if self.temporal_model is not None:
             data["temporal"] = self.temporal_model.to_dict()
 
+        if self.apply_irf != self._apply_irf_default:
+            data["apply_irf"] = self.apply_irf
+
+        if self.datasets_names is not None:
+            data["datasets_names"] = self.datasets_names
+
         return data
 
     @classmethod
@@ -227,6 +318,7 @@ class SkyModel(SkyModelBase):
         spectral_model = model_class.from_dict(data["spectral"])
 
         spatial_data = data.get("spatial")
+
         if spatial_data is not None:
             model_class = SPATIAL_MODELS.get_cls(spatial_data["type"])
             spatial_model = model_class.from_dict(spatial_data)
@@ -234,6 +326,7 @@ class SkyModel(SkyModelBase):
             spatial_model = None
 
         temporal_data = data.get("temporal")
+
         if temporal_data is not None:
             model_class = TEMPORAL_MODELS.get_cls(temporal_data["type"])
             temporal_model = model_class.from_dict(temporal_data)
@@ -245,12 +338,16 @@ class SkyModel(SkyModelBase):
             spatial_model=spatial_model,
             spectral_model=spectral_model,
             temporal_model=temporal_model,
+            apply_irf=data.get("apply_irf", cls._apply_irf_default),
+            datasets_names=data.get("datasets_names"),
         )
 
     def __str__(self):
         str_ = self.__class__.__name__ + "\n\n"
         str_ += "\t{:26}: {}\n".format("Name", self.name)
 
+        str_ += "\t{:26}: {}\n".format("Datasets names", self.datasets_names)
+
         str_ += "\t{:26}: {}\n".format("Spectral model type", self.spectral_model.tag)
 
         if self.spatial_model is not None:
@@ -262,7 +359,7 @@ class SkyModel(SkyModelBase):
         if self.temporal_model is not None:
             temporal_type = self.temporal_model.tag
         else:
-            temporal_type = ""
+            temporal_type = "None"
         str_ += "\t{:26}: {}\n".format("Temporal model type", temporal_type)
 
         str_ += "\tParameters:\n"
@@ -302,6 +399,8 @@ class SkyDiffuseCube(SkyModelBase):
     tilt = Parameter("tilt", 0, unit="", frozen=True)
     reference = Parameter("reference", "1 TeV", frozen=True)
 
+    _apply_irf_default = {"exposure": True, "psf": True, "edisp": True}
+
     def __init__(
         self,
         map,
@@ -312,15 +411,12 @@ class SkyDiffuseCube(SkyModelBase):
         interp_kwargs=None,
         name=None,
         filename=None,
+        apply_irf=None,
+        datasets_names=None,
     ):
 
         self._name = make_name(name)
 
-        axis = map.geom.get_axis_by_name("energy")
-
-        if axis.node_type != "center":
-            raise ValueError('Need a map with energy axis node_type="center"')
-
         self.map = map
         self.meta = {} if meta is None else meta
         self.filename = filename
@@ -335,6 +431,11 @@ class SkyDiffuseCube(SkyModelBase):
         self._cached_value = None
         self._cached_coordinates = (None, None, None)
 
+        if apply_irf is None:
+            apply_irf = self._apply_irf_default.copy()
+
+        self.apply_irf = apply_irf
+        self.datasets_names = datasets_names
         super().__init__(norm=norm, tilt=tilt, reference=reference)
 
     @property
@@ -356,22 +457,30 @@ class SkyDiffuseCube(SkyModelBase):
             The default used if none is filename.
         """
         m = Map.read(filename, **kwargs)
+
         if m.unit == "":
             m.unit = "cm-2 s-1 MeV-1 sr-1"
+
         if name is None:
             name = Path(filename).stem
+
+        if m.geom.axes[0].name == "energy":
+            m.geom.axes[0].name = "energy_true"
+
         return cls(m, name=name, filename=filename)
 
     def _interpolate(self, lon, lat, energy):
         coord = {
             "lon": lon.to_value("deg"),
             "lat": lat.to_value("deg"),
-            "energy": energy,
+            "energy_true": energy,
         }
         return self.map.interp_by_coord(coord, **self._interp_kwargs)
 
-    def evaluate(self, lon, lat, energy):
-        """Evaluate model."""
+    def evaluate(self, lon, lat, energy, time=None):
+        """Evaluate model.
+        passing time does not make sense here - passed just to match arguments
+        of SkyModel.evaluate"""
         is_cached_coord = [
             _ is coord for _, coord in zip((lon, lat, energy), self._cached_coordinates)
         ]
@@ -384,15 +493,35 @@ class SkyDiffuseCube(SkyModelBase):
             self._cached_coordinates = (lon, lat, energy)
             self._cached_value = self._interpolate(lon, lat, energy)
 
-        norm = self.parameters["norm"].value
+        norm = self.norm.value
+        tilt = self.tilt.value
+        reference = self.reference.quantity
 
-        tilt = self.parameters["tilt"].value
-        reference = self.parameters["reference"].quantity
         tilt_factor = np.power((energy / reference).to(""), -tilt)
 
         val = norm * self._cached_value * tilt_factor.value
         return u.Quantity(val, self.map.unit, copy=False)
 
+    def integrate_geom(self, geom, gti=None):
+        """Integrate model on `~gammapy.maps.Geom`.
+
+        Parameters
+        ----------
+        geom : `Geom`
+            Map geometry
+        gti : `GTI`
+            GIT table (currently not being used...)
+
+        Returns
+        -------
+        flux : `Map`
+            Predicted flux map
+        """
+        # TODO: implement better integration method?
+        value = self.evaluate_geom(geom)
+        value = value * geom.bin_volume()
+        return Map.from_geom(geom=geom, data=value.value, unit=value.unit)
+
     def copy(self, name=None):
         """A shallow copy"""
         new = copy.copy(self)
@@ -415,9 +544,24 @@ class SkyDiffuseCube(SkyModelBase):
 
     @classmethod
     def from_dict(cls, data):
-        model = cls.read(data["filename"])
-        model._update_from_dict(data)
-        return model
+        parameters = Parameters.from_dict(data["parameters"])
+
+        filename = data["filename"]
+
+        map_ = cls.read(filename).map
+
+        apply_irf = data.get("apply_irf", cls._apply_irf_default)
+        datasets_names = data.get("datasets_names")
+        name = data.get("name")
+
+        return cls.from_parameters(
+            parameters=parameters,
+            map=map_,
+            apply_irf=apply_irf,
+            datasets_names=datasets_names,
+            filename=filename,
+            name=name,
+        )
 
     def to_dict(self):
         data = super().to_dict()
@@ -427,11 +571,19 @@ class SkyDiffuseCube(SkyModelBase):
 
         # Move parameters at the end
         data["parameters"] = data.pop("parameters")
+
+        if self.apply_irf != self._apply_irf_default:
+            data["apply_irf"] = self.apply_irf
+
+        if self.datasets_names is not None:
+            data["datasets_names"] = self.datasets_names
+
         return data
 
     def __str__(self):
         str_ = self.__class__.__name__ + "\n\n"
         str_ += "\t{:26}: {}\n".format("Name", self.name)
+        str_ += "\t{:26}: {}\n".format("Datasets names", self.datasets_names)
         str_ += "\tParameters:\n"
         info = _get_parameters_str(self.parameters)
         lines = info.split("\n")
@@ -471,6 +623,7 @@ class BackgroundModel(Model):
         reference=reference.quantity,
         name=None,
         filename=None,
+        datasets_names=None,
     ):
         axis = map.geom.get_axis_by_name("energy")
         if axis.node_type != "edges":
@@ -481,6 +634,13 @@ class BackgroundModel(Model):
         self._name = make_name(name)
         self.filename = filename
 
+        if isinstance(datasets_names, list):
+            if len(datasets_names) != 1:
+                raise ValueError(
+                    "Currently background models can only be assigned to one dataset."
+                )
+
+        self.datasets_names = datasets_names
         super().__init__(norm=norm, tilt=tilt, reference=reference)
 
     @property
@@ -502,9 +662,9 @@ class BackgroundModel(Model):
         background_map : `~gammapy.maps.Map`
             Background evaluated on the Map
         """
-        norm = self.parameters["norm"].value
-        tilt = self.parameters["tilt"].value
-        reference = self.parameters["reference"].quantity
+        norm = self.norm.value
+        tilt = self.tilt.value
+        reference = self.reference.quantity
         tilt_factor = np.power((self.energy_center / reference).to(""), -tilt)
         back_values = norm * self.map.data * tilt_factor.value
         return self.map.copy(data=back_values)
@@ -513,23 +673,41 @@ class BackgroundModel(Model):
         data = {}
         data["name"] = self.name
         data.update(super().to_dict())
+
         if self.filename is not None:
             data["filename"] = self.filename
+
         data["parameters"] = data.pop("parameters")
+
+        if self.datasets_names is not None:
+            data["datasets_names"] = self.datasets_names
+
         return data
 
     @classmethod
     def from_dict(cls, data):
         if "filename" in data:
-            map = Map.read(data["filename"])
+            bkg_map = Map.read(data["filename"])
         elif "map" in data:
-            map = data["map"]
+            bkg_map = data["map"]
         else:
-            raise ValueError("Requires either filename or `Map` object")
+            # TODO: for now create a fake map for serialization,
+            # uptdated in MapDataset.from_dict()
+            axis = MapAxis.from_edges(np.logspace(-1, 1, 2), unit=u.TeV, name="energy")
+            geom = WcsGeom.create(
+                skydir=(0, 0), npix=(1, 1), frame="galactic", axes=[axis]
+            )
+            bkg_map = Map.from_geom(geom)
 
-        model = cls(map=map, name=data["name"])
-        model._update_from_dict(data)
-        return model
+        parameters = Parameters.from_dict(data["parameters"])
+
+        return cls.from_parameters(
+            parameters=parameters,
+            map=bkg_map,
+            name=data["name"],
+            datasets_names=data.get("datasets_names"),
+            filename=data.get("filename"),
+        )
 
     def copy(self, name=None):
         """A deep copy."""
@@ -560,9 +738,8 @@ class BackgroundModel(Model):
         cutout_kwargs = {"position": position, "width": width, "mode": mode}
 
         bkg_map = self.map.cutout(**cutout_kwargs)
-        model = self.__class__(bkg_map, name=name)
-        model.parameters.update_from_dict(self.parameters.to_dict())
-        return model
+        parameters = self.parameters.copy()
+        return self.__class__.from_parameters(parameters, map=bkg_map, name=name)
 
     def stack(self, other, weights=None):
         """Stack background model in place.
@@ -586,6 +763,8 @@ class BackgroundModel(Model):
     def __str__(self):
         str_ = self.__class__.__name__ + "\n\n"
         str_ += "\t{:26}: {}\n".format("Name", self.name)
+        str_ += "\t{:26}: {}\n".format("Datasets names", self.datasets_names)
+
         str_ += "\tParameters:\n"
         info = _get_parameters_str(self.parameters)
         lines = info.split("\n")
@@ -594,6 +773,16 @@ class BackgroundModel(Model):
         str_ += "\n\n"
         return str_.expandtabs(tabsize=2)
 
+    @property
+    def position(self):
+        """`~astropy.coordinates.SkyCoord`"""
+        return self.map.geom.center_skydir
+
+    @property
+    def evaluation_radius(self):
+        """`~astropy.coordinates.Angle`"""
+        return np.max(self.map.geom.width) / 2.0
+
 
 def create_fermi_isotropic_diffuse_model(filename, **kwargs):
     """Read Fermi isotropic diffuse model.
