@@ -14,7 +14,7 @@ from regions import (
     PolygonSkyRegion,
 )
 from gammapy.maps import Map, WcsGeom
-from gammapy.modeling import Parameter
+from gammapy.modeling import Parameter, Parameters
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.scripts import make_path
 from .core import Model
@@ -56,6 +56,13 @@ class SpatialModel(Model):
         lat = self.lat_0.quantity
         return SkyCoord(lon, lat, frame=self.frame)
 
+    @position.setter
+    def position(self, skycoord):
+        """Spatial model center position"""
+        coord = skycoord.transform_to(self.frame)
+        self.lon_0.quantity = coord.data.lon
+        self.lat_0.quantity = coord.data.lat
+
     # TODO: get rid of this!
     _phi_0 = 0.0
 
@@ -70,7 +77,7 @@ class SpatialModel(Model):
     @property
     def position_error(self):
         """Get 95% containment position error as (`~regions.EllipseSkyRegion`)"""
-        if self.parameters.covariance is None:
+        if self.covariance is None:
             return EllipseSkyRegion(
                 center=self.position,
                 height=np.nan * u.deg,
@@ -78,7 +85,7 @@ class SpatialModel(Model):
                 angle=np.nan * u.deg,
             )
         pars = self.parameters
-        sub_covar = pars.get_subcovariance(["lon_0", "lat_0"])
+        sub_covar = self.covariance.get_subcovariance(["lon_0", "lat_0"]).data.copy()
         cos_lat = np.cos(self.lat_0.quantity.to_value("rad"))
         sub_covar[0, 0] *= cos_lat ** 2.0
         sub_covar[0, 1] *= cos_lat
@@ -106,6 +113,12 @@ class SpatialModel(Model):
         coords = geom.get_coord(frame=self.frame)
         return self(coords.lon, coords.lat)
 
+    def integrate(self, geom):
+        """Integrate model on `~gammapy.maps.Geom`."""
+        values = self.evaluate_geom(geom)
+        data = values * geom.solid_angle()
+        return Map.from_geom(geom=geom, data=data.value, unit=data.unit)
+
     def to_dict(self):
         """Create dict for YAML serilisation"""
         data = super().to_dict()
@@ -144,6 +157,43 @@ class SpatialModel(Model):
         data = self.evaluate_geom(geom)
         m = Map.from_geom(geom, data=data.value, unit=data.unit)
         _, ax, _ = m.plot(ax=ax, **kwargs)
+
+        return ax
+
+    def plot_error(self, ax=None, **kwargs):
+        """Plot position error
+
+        Parameters
+        ----------
+        ax : `~matplotlib.axes.Axes`, optional
+            Axis
+        **kwargs : dict
+            Keyword arguments passed to `~gammapy.maps.WcsMap.plot()`
+
+        Returns
+        -------
+        ax : `~matplotlib.axes.Axes`, optional
+            Axis
+        """
+        import matplotlib.pyplot as plt
+
+        # plot center position
+        lon, lat = self.lon_0.value, self.lat_0.value
+
+        ax = plt.gca() if ax is None else ax
+
+        kwargs.setdefault("marker", "x")
+        kwargs.setdefault("color", "red")
+        kwargs.setdefault("label", "position")
+
+        ax.scatter(lon, lat, transform=ax.get_transform(self.frame), **kwargs)
+
+        # plot position error
+        if not np.all(self.covariance.data == 0):
+            region = self.position_error.to_pixel(ax.wcs)
+            artist = region.as_artist(facecolor="none", edgecolor=kwargs["color"])
+            ax.add_artist(artist)
+
         return ax
 
 
@@ -185,10 +235,26 @@ class PointSpatialModel(SpatialModel):
 
     def evaluate_geom(self, geom):
         """Evaluate model on `~gammapy.maps.Geom`."""
-        x, y = geom.get_pix()
+        values = self.integrate_geom(geom).data
+        return values / geom.solid_angle()
+
+    def integrate_geom(self, geom):
+        """Integrate model on `~gammapy.maps.Geom`
+
+        Parameters
+        ----------
+        geom : `Geom`
+            Map geometry
+
+        Returns
+        -------
+        flux : `Map`
+            Predicted flux map
+        """
+        x, y = geom.get_pix()[0:2]
         x0, y0 = self.position.to_pixel(geom.wcs)
-        w = self._grid_weights(x, y, x0, y0)
-        return w / geom.solid_angle()
+        data = self._grid_weights(x, y, x0, y0)
+        return Map.from_geom(geom=geom, data=data, unit="")
 
     def to_region(self, **kwargs):
         """Model outline (`~regions.PointSkyRegion`)."""
@@ -298,7 +364,7 @@ class DiskSpatialModel(SpatialModel):
 
         Set to the length of the semi-major axis.
         """
-        return self.parameters["r_0"].quantity
+        return self.r_0.quantity
 
     @staticmethod
     def _evaluate_norm_factor(r_0, e):
@@ -382,7 +448,7 @@ class ShellSpatialModel(SpatialModel):
 
         Set to :math:`r_\text{out}`.
         """
-        return self.parameters["radius"].quantity + self.parameters["width"].quantity
+        return self.radius.quantity + self.width.quantity
 
     @staticmethod
     def evaluate(lon, lat, lon_0, lat_0, radius, width):
@@ -428,6 +494,7 @@ class ConstantSpatialModel(SpatialModel):
 
     frame = "icrs"
     evaluation_radius = None
+    position = SkyCoord("0 deg", "0 deg", frame=frame)
 
     def to_dict(self):
         """Create dict for YAML serilisation"""
@@ -556,9 +623,18 @@ class TemplateSpatialModel(SpatialModel):
 
     @classmethod
     def from_dict(cls, data):
-        model = cls.read(data["filename"], normalize=data.get("normalize", True))
-        model._update_from_dict(data)
-        return model
+        m = Map.read(data["filename"])
+
+        if m.unit == "":
+            m.unit = "sr-1"
+
+        parameters = Parameters.from_dict(data["parameters"])
+        return cls.from_parameters(
+            parameters=parameters,
+            map=m,
+            filename=data["filename"],
+            normalize=data.get("normalize", True),
+        )
 
     def to_dict(self):
         """Create dict for YAML serilisation"""
