@@ -5,10 +5,11 @@ import numpy as np
 import scipy.optimize
 import scipy.special
 import astropy.units as u
+from astropy import constants as const
 from astropy.table import Table
 from gammapy.maps import MapAxis
 from gammapy.maps.utils import edges_from_lo_hi
-from gammapy.modeling import Parameter, Parameters
+from gammapy.modeling import Covariance, Parameter, Parameters
 from gammapy.utils.integrate import evaluate_integral_pwl, trapz_loglog
 from gammapy.utils.interpolation import ScaledRegularGridInterpolator
 from gammapy.utils.scripts import make_path
@@ -122,8 +123,8 @@ class SpectralModel(Model):
         dnde, dnde_error : tuple of `~astropy.units.Quantity`
             Tuple of flux and flux error.
         """
-        p_cov = self.parameters.covariance
-        eps = np.sqrt(np.diag(self.parameters.covariance)) * epsilon
+        p_cov = self.covariance
+        eps = np.sqrt(np.diag(p_cov)) * epsilon
 
         df_dp = self._evaluate_gradient(energy, eps)
         f_cov = df_dp.T @ p_cov @ df_dp
@@ -523,9 +524,8 @@ class PowerLawSpectralModel(SpectralModel):
         value : `~astropy.units.Quantity`
             Function value of the spectral model.
         """
-        p = self.parameters
-        base = value / p["amplitude"].quantity
-        return p["reference"].quantity * np.power(base, -1.0 / p["index"].value)
+        base = value / self.amplitude.quantity
+        return self.reference.quantity * np.power(base, -1.0 / self.index.value)
 
     @property
     def pivot_energy(self):
@@ -537,10 +537,10 @@ class PowerLawSpectralModel(SpectralModel):
 
         Formula (1) in https://arxiv.org/pdf/0910.4881.pdf
         """
-        index_err = self.parameters.error("index")
+        index_err = self.index.error
         reference = self.reference.quantity
         amplitude = self.amplitude.quantity
-        cov_index_ampl = self.parameters.covariance[0, 1] * amplitude.unit
+        cov_index_ampl = self.covariance.data[0, 1] * amplitude.unit
         return reference * np.exp(cov_index_ampl / (amplitude * index_err ** 2))
 
 
@@ -590,17 +590,15 @@ class PowerLaw2SpectralModel(SpectralModel):
         emin, emax : `~astropy.units.Quantity`
             Lower and upper bound of integration range.
         """
-        pars = self.parameters
-
-        temp1 = np.power(emax, -pars["index"].value + 1)
-        temp2 = np.power(emin, -pars["index"].value + 1)
+        temp1 = np.power(emax, -self.index.value + 1)
+        temp2 = np.power(emin, -self.index.value + 1)
         top = temp1 - temp2
 
-        temp1 = np.power(pars["emax"].quantity, -pars["index"].value + 1)
-        temp2 = np.power(pars["emin"].quantity, -pars["index"].value + 1)
+        temp1 = np.power(self.emax.quantity, -self.index.value + 1)
+        temp2 = np.power(self.emin.quantity, -self.index.value + 1)
         bottom = temp1 - temp2
 
-        return pars["amplitude"].quantity * top / bottom
+        return self.amplitude.quantity * top / bottom
 
     def inverse(self, value):
         """Return energy for a given function value of the spectral model.
@@ -610,13 +608,10 @@ class PowerLaw2SpectralModel(SpectralModel):
         value : `~astropy.units.Quantity`
             Function value of the spectral model.
         """
-        p = self.parameters
-        amplitude, index, emin, emax = (
-            p["amplitude"].quantity,
-            p["index"].value,
-            p["emin"].quantity,
-            p["emax"].quantity,
-        )
+        amplitude = self.amplitude.quantity
+        index = self.index.value
+        emin = self.emin.quantity
+        emax = self.emax.quantity
 
         # to get the energies dimensionless we use a modified formula
         top = -index + 1
@@ -657,6 +652,7 @@ class SmoothBrokenPowerLawSpectralModel(SpectralModel):
     @staticmethod
     def evaluate(energy, index1, index2, amplitude, ebreak, reference, beta):
         """Evaluate the model (static function)."""
+        beta *= np.sign(index2 - index1)
         pwl = amplitude * (energy / reference) ** (-index1)
         brk = (1 + (energy / ebreak) ** ((index2 - index1) / beta)) ** (-beta)
         return pwl * brk
@@ -706,11 +702,11 @@ class ExpCutoffPowerLawSpectralModel(SpectralModel):
         .. math::
             E_{Peak} =  \left(\frac{2 - \Gamma}{\alpha}\right)^{1/\alpha} / \lambda
         """
-        p = self.parameters
-        reference = p["reference"].quantity
-        index = p["index"].quantity
-        lambda_ = p["lambda_"].quantity
-        alpha = p["alpha"].quantity
+        reference = self.reference.quantity
+        index = self.index.quantity
+        lambda_ = self.lambda_.quantity
+        alpha = self.alpha.quantity
+
         if index >= 2 or lambda_ == 0.0 or alpha == 0.0:
             return np.nan * reference.unit
         else:
@@ -872,10 +868,9 @@ class LogParabolaSpectralModel(SpectralModel):
         .. math::
             E_{Peak} = E_{0} \exp{ (2 - \alpha) / (2 * \beta)}
         """
-        p = self.parameters
-        reference = p["reference"].quantity
-        alpha = p["alpha"].quantity
-        beta = p["beta"].quantity
+        reference = self.reference.quantity
+        alpha = self.alpha.quantity
+        beta = self.beta.quantity
         return reference * np.exp((2 - alpha) / (2 * beta))
 
 
@@ -989,7 +984,7 @@ class TemplateSpectralModel(SpectralModel):
     def to_dict(self):
         return {
             "type": self.tag,
-            "parameters": self.parameters.to_dict()["parameters"],
+            "parameters": self.parameters.to_dict(),
             "energy": {
                 "data": self.energy.data.tolist(),
                 "unit": str(self.energy.unit),
@@ -1002,11 +997,10 @@ class TemplateSpectralModel(SpectralModel):
 
     @classmethod
     def from_dict(cls, data):
+        parameters = Parameters.from_dict(data["parameters"])
         energy = u.Quantity(data["energy"]["data"], data["energy"]["unit"])
         values = u.Quantity(data["values"]["data"], data["values"]["unit"])
-        model = cls(energy=energy, values=values)
-        model._update_from_dict(data)
-        return model
+        return cls.from_parameters(parameters, energy=energy, values=values)
 
 
 class ScaleSpectralModel(SpectralModel):
@@ -1025,11 +1019,15 @@ class ScaleSpectralModel(SpectralModel):
 
     def __init__(self, model, norm=norm.quantity):
         self.model = model
+        self._covariance = None
         super().__init__(norm=norm)
 
     def evaluate(self, energy, norm):
         return norm * self.model(energy)
 
+    def integral(self, emin, emax, **kwargs):
+        return self.norm.value * self.model.integral(emin, emax, **kwargs)
+
 
 class Absorption:
     r"""Gamma-ray absorption models.
@@ -1212,53 +1210,66 @@ class AbsorbedSpectralModel(SpectralModel):
         Spectral model.
     absorption : `Absorption`
         Absorption model.
-    parameter : float
-        parameter value for absorption model
-    parameter_name : str, optional
-        parameter name
+    redshift : float
+        Redshift of the absorption model
     alpha_norm: float
         Norm of the EBL model
     """
 
     tag = "AbsorbedSpectralModel"
+    alpha_norm = Parameter("alpha_norm", 1.0, frozen=True)
+    redshift = Parameter("redshift", 0.1, frozen=True)
 
     def __init__(
-        self,
-        spectral_model,
-        absorption,
-        parameter,
-        parameter_name="redshift",
-        alpha_norm=1.0,
+        self, spectral_model, absorption, redshift, alpha_norm=alpha_norm.quantity,
     ):
         self.spectral_model = spectral_model
         self.absorption = absorption
-        self.parameter = parameter
-        self.parameter_name = parameter_name
+
         min_ = self.absorption.param.min()
         max_ = self.absorption.param.max()
 
-        par = Parameter(parameter_name, parameter, min=min_, max=max_, frozen=True)
-        alpha_norm = Parameter("alpha_norm", alpha_norm, frozen=True)
-        parameters = Parameters([par, alpha_norm])
+        redshift = Parameter("redshift", redshift, frozen=True, min=min_, max=max_)
+        super().__init__(redshift=redshift, alpha_norm=alpha_norm)
 
-        super()._init_from_parameters(parameters)
+    def _check_covariance(self):
+        if not self.parameters == self._covariance.parameters:
+            self._covariance = Covariance(self.parameters)
+
+    @property
+    def covariance(self):
+        self._check_covariance()
+        self._covariance.set_subcovariance(self.spectral_model.covariance)
+        return self._covariance
+
+    @covariance.setter
+    def covariance(self, covariance):
+        self._check_covariance()
+        self._covariance.data = covariance
+
+        subcovar = self._covariance.get_subcovariance(
+            self.spectral_model.covariance.parameters
+        )
+        self.spectral_model.covariance = subcovar
 
     @property
     def parameters(self):
-        return self._parameters + self.spectral_model.parameters
+        return (
+            Parameters([self.redshift, self.alpha_norm])
+            + self.spectral_model.parameters
+        )
 
     def evaluate(self, energy, **kwargs):
         """Evaluate the model at a given energy."""
         # assign redshift value and remove it from dictionary
         # since it does not belong to the spectral model
-        parameter = kwargs[self.parameter_name]
-        del kwargs[self.parameter_name]
-        del kwargs["alpha_norm"]
+        parameter = kwargs.pop("redshift")
+        alpha_norm = kwargs.pop("alpha_norm")
 
         dnde = self.spectral_model.evaluate(energy=energy, **kwargs)
         absorption = self.absorption.evaluate(energy=energy, parameter=parameter)
         # Power rule: (e ^ a) ^ b = e ^ (a * b)
-        absorption = np.power(absorption, self.alpha_norm.value)
+        absorption = np.power(absorption, alpha_norm)
         return dnde * absorption
 
     def to_dict(self):
@@ -1266,11 +1277,8 @@ class AbsorbedSpectralModel(SpectralModel):
             "type": self.tag,
             "base_model": self.spectral_model.to_dict(),
             "absorption": self.absorption.to_dict(),
-            "absorption_parameter": {
-                "name": self.parameter_name,
-                "value": self.parameter,
-            },
-            "parameters": self._parameters.to_dict()["parameters"],
+            "absorption_parameter": {"name": "redshift", "value": self.redshift.value,},
+            "parameters": Parameters([self.redshift, self.alpha_norm]).to_dict(),
         }
 
     @classmethod
@@ -1278,13 +1286,12 @@ class AbsorbedSpectralModel(SpectralModel):
         from gammapy.modeling.models import SPECTRAL_MODELS
 
         model_class = SPECTRAL_MODELS.get_cls(data["base_model"]["type"])
+
         model = cls(
             spectral_model=model_class.from_dict(data["base_model"]),
             absorption=Absorption.from_dict(data["absorption"]),
-            parameter=data["absorption_parameter"]["value"],
-            parameter_name=data["absorption_parameter"]["name"],
+            redshift=data["absorption_parameter"]["value"],
         )
-        model._update_from_dict(data)
         return model
 
 
@@ -1305,11 +1312,16 @@ class NaimaSpectralModel(SpectralModel):
         in case of a `~naima.models.InverseCompton` model. It can be a subset of the
         `seed_photon_fields` list defining the `radiative_model`. Default is the whole list
         of photon fields
+    nested_models : dict
+        Additionnal parameters for nested models not supplied by the radiative model,
+        for now this is used  only for synchrotron self-compton model
     """
 
     tag = "NaimaSpectralModel"
 
-    def __init__(self, radiative_model, distance=1.0 * u.kpc, seed=None):
+    def __init__(
+        self, radiative_model, distance=1.0 * u.kpc, seed=None, nested_models=None
+    ):
         import naima
 
         self.radiative_model = radiative_model
@@ -1317,6 +1329,11 @@ class NaimaSpectralModel(SpectralModel):
         self.distance = u.Quantity(distance)
         self.seed = seed
 
+        if nested_models is None:
+            nested_models = {}
+
+        self.nested_models = nested_models
+
         if isinstance(self._particle_distribution, naima.models.TableModel):
             param_names = ["amplitude"]
         else:
@@ -1335,21 +1352,82 @@ class NaimaSpectralModel(SpectralModel):
             parameter = Parameter("B", value)
             parameters.append(parameter)
 
-        super()._init_from_parameters(parameters)
+        # In case of a synchrotron self compton model, append B and Rpwn to the fittable parameters
+        if (
+            isinstance(self.radiative_model, naima.models.InverseCompton)
+            and "SSC" in self.nested_models
+        ):
+            B = self.nested_models["SSC"]["B"]
+            radius = self.nested_models["SSC"]["radius"]
+            parameters.append(Parameter("B", B))
+            parameters.append(Parameter("radius", radius, frozen=True))
+
+        self.default_parameters = Parameters(parameters)
+        super().__init__()
+
+    def _evaluate_ssc(
+        self, energy,
+    ):
+        """
+        Compute photon density spectrum from synchrotron emission for synchrotron self-compton model,
+        assuming uniform synchrotron emissivity inside a sphere of radius R
+        (see Section 4.1 of Atoyan & Aharonian 1996)
+
+        based on :
+        "https://naima.readthedocs.io/en/latest/examples.html#crab-nebula-ssc-model"
+
+        """
+        import naima
+
+        SYN = naima.models.Synchrotron(
+            self._particle_distribution,
+            B=self.B.quantity,
+            Eemax=self.radiative_model.Eemax,
+            Eemin=self.radiative_model.Eemin,
+        )
+
+        Esy = np.logspace(-7, 9, 100) * u.eV
+        Lsy = SYN.flux(Esy, distance=0 * u.cm)  # use distance 0 to get luminosity
+        phn_sy = Lsy / (4 * np.pi * self.radius.quantity ** 2 * const.c) * 2.24
+        # The factor 2.24 comes from the assumption on uniform synchrotron
+        # emissivity inside a sphere
+
+        if "SSC" not in self.radiative_model.seed_photon_fields:
+            self.radiative_model.seed_photon_fields["SSC"] = {
+                "isotropic": True,
+                "type": "array",
+                "energy": Esy,
+                "photon_density": phn_sy,
+            }
+        else:
+            self.radiative_model.seed_photon_fields["SSC"]["photon_density"] = phn_sy
+
+        dnde = self.radiative_model.flux(
+            energy, seed=self.seed, distance=self.distance
+        ) + SYN.flux(energy, distance=self.distance)
+        return dnde
 
     def evaluate(self, energy, **kwargs):
         """Evaluate the model."""
+        import naima
+
         for name, value in kwargs.items():
             setattr(self._particle_distribution, name, value)
 
-        # Flattening the input energy list and later reshaping the flux list
-        # prevents some radiative models from displaying broadcasting problems.
-        if self.seed is None:
-            dnde = self.radiative_model.flux(energy.flatten(), distance=self.distance)
-        else:
+        if "B" in self.radiative_model.param_names:
+            self.radiative_model.B = self.B.quantity
+
+        if (
+            isinstance(self.radiative_model, naima.models.InverseCompton)
+            and "SSC" in self.nested_models
+        ):
+            dnde = self._evaluate_ssc(energy.flatten())
+        elif self.seed is not None:
             dnde = self.radiative_model.flux(
                 energy.flatten(), seed=self.seed, distance=self.distance
             )
+        else:
+            dnde = self.radiative_model.flux(energy.flatten(), distance=self.distance)
 
         dnde = dnde.reshape(energy.shape)
         unit = 1 / (energy.unit * u.cm ** 2 * u.s)
@@ -1403,16 +1481,15 @@ class GaussianSpectralModel(SpectralModel):
         """
         # kwargs are passed to this function but not used
         # this is to get a consistent API with SpectralModel.integral()
-        pars = self.parameters
         u_min = (
-            (emin - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+            (emin - self.mean.quantity) / (np.sqrt(2) * self.sigma.quantity)
         ).to_value("")
         u_max = (
-            (emax - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+            (emax - self.mean.quantity) / (np.sqrt(2) * self.sigma.quantity)
         ).to_value("")
 
         return (
-            pars["norm"].quantity
+            self.norm.quantity
             / 2
             * (scipy.special.erf(u_max) - scipy.special.erf(u_min))
         )
@@ -1431,15 +1508,14 @@ class GaussianSpectralModel(SpectralModel):
         emin, emax : `~astropy.units.Quantity`
             Lower and upper bound of integration range.
         """
-        pars = self.parameters
         u_min = (
-            (emin - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+            (emin - self.mean.quantity) / (np.sqrt(2) * self.sigma.quantity)
         ).to_value("")
         u_max = (
-            (emax - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+            (emax - self.mean.quantity) / (np.sqrt(2) * self.sigma.quantity)
         ).to_value("")
-        a = pars["norm"].quantity * pars["sigma"].quantity / np.sqrt(2 * np.pi)
-        b = pars["norm"].quantity * pars["mean"].quantity / 2
+        a = self.norm.quantity * self.sigma.quantity / np.sqrt(2 * np.pi)
+        b = self.norm.quantity * self.mean.quantity / 2
         return a * (np.exp(-(u_min ** 2)) - np.exp(-(u_max ** 2))) + b * (
             scipy.special.erf(u_max) - scipy.special.erf(u_min)
         )
