@@ -3,13 +3,15 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 import astropy.units as u
-from gammapy.cube import PSFKernel
-from gammapy.cube.fit import MapEvaluator
-from gammapy.irf import EDispKernel
+from astropy.time import Time
+from gammapy.data.gti import GTI
+from gammapy.datasets.map import MapEvaluator
+from gammapy.irf import EDispKernel, PSFKernel
 from gammapy.maps import Map, MapAxis, WcsGeom
 from gammapy.modeling.models import (
     BackgroundModel,
     ConstantSpectralModel,
+    ConstantTemporalModel,
     GaussianSpatialModel,
     Models,
     PointSpatialModel,
@@ -29,14 +31,27 @@ def sky_model():
     spectral_model = PowerLawSpectralModel(
         index=2, amplitude="1e-11 cm-2 s-1 TeV-1", reference="1 TeV"
     )
+    temporal_model = ConstantTemporalModel()
     return SkyModel(
-        spatial_model=spatial_model, spectral_model=spectral_model, name="source-1"
+        spatial_model=spatial_model,
+        spectral_model=spectral_model,
+        temporal_model=temporal_model,
+        name="source-1",
     )
 
 
+@pytest.fixture(scope="session")
+def gti():
+    start = [1, 3, 5] * u.day
+    stop = [2, 3.5, 6] * u.day
+    t_ref = Time(55555, format="mjd")
+    gti = GTI.create(start, stop, reference_time=t_ref)
+    return gti
+
+
 @pytest.fixture(scope="session")
 def diffuse_model():
-    axis = MapAxis.from_nodes([0.1, 100], name="energy", unit="TeV", interp="log")
+    axis = MapAxis.from_nodes([0.1, 100], name="energy_true", unit="TeV", interp="log")
     m = Map.create(
         npix=(4, 3), binsz=2, axes=[axis], unit="cm-2 s-1 MeV-1 sr-1", frame="galactic"
     )
@@ -52,7 +67,7 @@ def geom():
 
 @pytest.fixture(scope="session")
 def geom_true():
-    axis = MapAxis.from_edges(np.logspace(-1, 1, 4), unit=u.TeV, name="energy")
+    axis = MapAxis.from_edges(np.logspace(-1, 1, 4), unit=u.TeV, name="energy_true")
     return WcsGeom.create(skydir=(0, 0), npix=(5, 4), frame="galactic", axes=[axis])
 
 
@@ -74,7 +89,7 @@ def background(geom):
 @pytest.fixture(scope="session")
 def edisp(geom, geom_true):
     e_reco = geom.get_axis_by_name("energy").edges
-    e_true = geom_true.get_axis_by_name("energy").edges
+    e_true = geom_true.get_axis_by_name("energy_true").edges
     return EDispKernel.from_diagonal_response(e_true=e_true, e_reco=e_reco)
 
 
@@ -85,8 +100,8 @@ def psf(geom_true):
 
 
 @pytest.fixture(scope="session")
-def evaluator(sky_model, exposure, psf, edisp):
-    return MapEvaluator(sky_model, exposure, psf=psf, edisp=edisp)
+def evaluator(sky_model, exposure, psf, edisp, gti):
+    return MapEvaluator(sky_model, exposure, psf=psf, edisp=edisp, gti=gti)
 
 
 @pytest.fixture(scope="session")
@@ -130,14 +145,14 @@ def test_sky_model_spatial_none_io(tmpdir):
     assert models["test"].spatial_model is None
 
 
-def test_sky_model_spatial_none_evaluate(geom):
+def test_sky_model_spatial_none_evaluate(geom_true, gti):
     pwl = PowerLawSpectralModel()
     model = SkyModel(spectral_model=pwl, name="test")
 
-    data = model.evaluate_geom(geom).to_value("cm-2 s-1 TeV-1")
+    data = model.evaluate_geom(geom_true, gti).to_value("cm-2 s-1 TeV-1")
 
-    assert data.shape == (2, 1, 1)
-    assert_allclose(data[0], 3.305785e-12)
+    assert data.shape == (3, 1, 1)
+    assert_allclose(data[0], 1.256774e-11, rtol=1e-6)
 
 
 def test_skymodel_addition(sky_model, sky_models, sky_models_2, diffuse_model):
@@ -178,18 +193,31 @@ def test_background_model(background):
     assert_allclose(bkg2.data.sum(), 7.352e-06, rtol=1e-3)
 
 
+def test_background_model_io(tmpdir, background):
+    filename = str(tmpdir / "test-bkg-file.fits")
+    bkg = BackgroundModel(background, norm=2.0, filename=filename)
+    bkg.map.write(filename, overwrite=True)
+    bkg_dict = bkg.to_dict()
+    bkg_read = bkg.from_dict(bkg_dict)
+
+    assert_allclose(
+        bkg_read.evaluate().data.sum(), background.data.sum() * 2.0, rtol=1e-3
+    )
+    assert bkg_read.filename == filename
+
+
 class TestSkyModels:
     @staticmethod
     def test_parameters(sky_models):
         parnames = [
+            "index",
+            "amplitude",
+            "reference",
             "lon_0",
             "lat_0",
             "sigma",
             "e",
             "phi",
-            "index",
-            "amplitude",
-            "reference",
         ] * 2
         assert sky_models.parameters.names == parnames
 
@@ -211,7 +239,7 @@ class TestSkyModels:
         model = sky_models["source-3"]
         assert model.name == "source-3"
 
-        with pytest.raises(IndexError):
+        with pytest.raises(ValueError):
             sky_models["spam"]
 
     @staticmethod
@@ -220,7 +248,7 @@ class TestSkyModels:
 
 
 @requires_data()
-def test_SkyModels_mutation(sky_model, sky_models, sky_models_2):
+def test_models_mutation(sky_model, sky_models, sky_models_2):
     mods = sky_models
 
     mods.insert(0, sky_model)
@@ -290,6 +318,17 @@ class TestSkyModel:
         assert q.shape == (5, 3, 4)
         assert_allclose(q.to_value("cm-2 s-1 TeV-1 deg-2"), 1.76879232e-13)
 
+    @staticmethod
+    def test_processing(sky_model):
+        assert sky_model.apply_irf == {"exposure": True, "psf": True, "edisp": True}
+        out = sky_model.to_dict()
+        assert "apply_irf" not in out
+
+        sky_model.apply_irf["edisp"] = False
+        out = sky_model.to_dict()
+        assert out["apply_irf"] == {"exposure": True, "psf": True, "edisp": False}
+        sky_model.apply_irf["edisp"] = True
+
 
 class TestSkyDiffuseCube:
     @staticmethod
@@ -343,6 +382,29 @@ class TestSkyDiffuseCube:
     def test_frame(diffuse_model):
         assert diffuse_model.frame == "galactic"
 
+    @staticmethod
+    def test_processing(diffuse_model):
+        assert diffuse_model.apply_irf == {"exposure": True, "psf": True, "edisp": True}
+        out = diffuse_model.to_dict()
+        assert "apply_irf" not in out
+
+        diffuse_model.apply_irf["edisp"] = False
+        out = diffuse_model.to_dict()
+        assert out["apply_irf"] == {"exposure": True, "psf": True, "edisp": False}
+        diffuse_model.apply_irf["edisp"] = True
+
+    @staticmethod
+    def test_datasets_name(diffuse_model):
+        assert diffuse_model.datasets_names is None
+
+        diffuse_model.datasets_names = ["1", "2"]
+        out = diffuse_model.to_dict()
+        assert out["datasets_names"] == ["1", "2"]
+
+        diffuse_model.datasets_names = None
+        out = diffuse_model.to_dict()
+        assert "datasets_names" not in out
+
 
 class TestSkyDiffuseCubeMapEvaluator:
     @staticmethod
@@ -356,8 +418,8 @@ class TestSkyDiffuseCubeMapEvaluator:
     @staticmethod
     def test_compute_flux(diffuse_evaluator):
         out = diffuse_evaluator.compute_flux()
-        assert out.shape == (3, 4, 5)
-        out = out.to("cm-2 s-1")
+        assert out.data.shape == (3, 4, 5)
+        out = out.quantity.to("cm-2 s-1")
         assert_allclose(out.value.sum(), 633263.444803, rtol=1e-5)
         assert_allclose(out.value[0, 0, 0], 1164.656176, rtol=1e-5)
 
@@ -406,10 +468,11 @@ class TestSkyModelMapEvaluator:
 
     @staticmethod
     def test_compute_flux(evaluator):
-        out = evaluator.compute_flux().to_value("cm-2 s-1")
+        out = evaluator.compute_flux()
+        out = out.quantity.to_value("cm-2 s-1")
         assert out.shape == (3, 4, 5)
-        assert_allclose(out.sum(), 1.291414e-12, rtol=1e-5)
-        assert_allclose(out[0, 0, 0], 4.630845e-14, rtol=1e-5)
+        assert_allclose(out.sum(), 2.213817e-12, rtol=1e-5)
+        assert_allclose(out[0, 0, 0], 7.938388e-14, rtol=1e-5)
 
     @staticmethod
     def test_apply_psf(evaluator):
@@ -417,8 +480,8 @@ class TestSkyModelMapEvaluator:
         npred = evaluator.apply_exposure(flux)
         out = evaluator.apply_psf(npred)
         assert out.data.shape == (3, 4, 5)
-        assert_allclose(out.data.sum(), 2.2530737e-06, rtol=1e-5)
-        assert_allclose(out.data[0, 0, 0], 2.407252e-08, rtol=1e-5)
+        assert_allclose(out.data.sum(), 3.862314e-06, rtol=1e-5)
+        assert_allclose(out.data[0, 0, 0], 4.126612e-08, rtol=1e-5)
 
     @staticmethod
     def test_apply_edisp(evaluator):
@@ -426,21 +489,23 @@ class TestSkyModelMapEvaluator:
         npred = evaluator.apply_exposure(flux)
         out = evaluator.apply_edisp(npred)
         assert out.data.shape == (2, 4, 5)
-        assert_allclose(out.data.sum(), 3.27582e-06, rtol=1e-5)
-        assert_allclose(out.data[0, 0, 0], 4.630845e-08, rtol=1e-5)
+        assert_allclose(out.data.sum(), 5.615601e-06, rtol=1e-5)
+        assert_allclose(out.data[0, 0, 0], 7.938388e-08, rtol=1e-5)
 
     @staticmethod
-    def test_compute_npred(evaluator):
+    def test_compute_npred(evaluator, gti):
         out = evaluator.compute_npred()
         assert out.data.shape == (2, 4, 5)
-        assert_allclose(out.data.sum(), 2.253073467739508e-06, rtol=1e-5)
-        assert_allclose(out.data[0, 0, 0], 2.407252e-08, rtol=1e-5)
+        assert_allclose(out.data.sum(), 3.862314e-06, rtol=1e-5)
+        assert_allclose(out.data[0, 0, 0], 4.126612e-08, rtol=1e-5)
 
 
 def test_sky_point_source():
     # Test special case of point source. Regression test for GH 2367.
 
-    energy_axis = MapAxis.from_edges([1, 10], unit="TeV", name="energy", interp="log")
+    energy_axis = MapAxis.from_edges(
+        [1, 10], unit="TeV", name="energy_true", interp="log"
+    )
     exposure = Map.create(
         skydir=(100, 70),
         npix=(4, 4),
@@ -459,7 +524,7 @@ def test_sky_point_source():
     spectral_model.const.value /= spectral_model.integral(1 * u.TeV, 10 * u.TeV).value
     model = SkyModel(spatial_model=spatial_model, spectral_model=spectral_model)
     evaluator = MapEvaluator(model=model, exposure=exposure)
-    flux = evaluator.compute_flux().to_value("cm-2 s-1")[0]
+    flux = evaluator.compute_flux().quantity.to_value("cm-2 s-1")[0]
 
     expected = [
         [0, 0, 0, 0],
