@@ -208,6 +208,20 @@ TEST_MODELS = [
         integral_1_10TeV=u.Quantity(0.9956923907948155, "cm-2 s-1"),
         eflux_1_10TeV=u.Quantity(2.2372256145972207, "TeV cm-2 s-1"),
     ),
+    dict(
+        name="sbpl-hard",
+        model=SmoothBrokenPowerLawSpectralModel(
+            index1=2.5 * u.Unit(""),
+            index2=1.5 * u.Unit(""),
+            amplitude=4 / u.cm ** 2 / u.s / u.TeV,
+            ebreak=0.5 * u.TeV,
+            reference=1 * u.TeV,
+            beta=1,
+        ),
+        val_at_2TeV=u.Quantity(3.5355339059327378, "cm-2 s-1 TeV-1"),
+        integral_1_10TeV=u.Quantity(13.522782989735022, "cm-2 s-1"),
+        eflux_1_10TeV=u.Quantity(40.06681812966845, "TeV cm-2 s-1"),
+    ),
 ]
 
 # Add compound models
@@ -307,7 +321,8 @@ def test_model_plot():
     pwl = PowerLawSpectralModel(
         amplitude=1e-12 * u.Unit("TeV-1 cm-2 s-1"), reference=1 * u.Unit("TeV"), index=2
     )
-    pwl.parameters.set_error(amplitude=0.1e-12 * u.Unit("TeV-1 cm-2 s-1"))
+    pwl.amplitude.error = 0.1e-12 * u.Unit("TeV-1 cm-2 s-1")
+
     with mpl_plot_check():
         pwl.plot((1 * u.TeV, 10 * u.TeV))
 
@@ -355,7 +370,7 @@ def test_absorption():
 
     # EBL + PWL model
     model = AbsorbedSpectralModel(
-        spectral_model=pwl, absorption=absorption, parameter=redshift
+        spectral_model=pwl, absorption=absorption, redshift=redshift
     )
 
     desired = u.Quantity(5.140765e-13, "TeV-1 s-1 cm-2")
@@ -364,22 +379,20 @@ def test_absorption():
 
     # EBL + PWL model: test if norm of EBL=0: it mean model =pwl
     model = AbsorbedSpectralModel(
-        spectral_model=pwl, absorption=absorption, alpha_norm=0, parameter=redshift
+        spectral_model=pwl, absorption=absorption, alpha_norm=0, redshift=redshift
     )
     assert_quantity_allclose(model(1 * u.TeV), pwl(1 * u.TeV), rtol=1e-3)
 
     # EBL + PWL model: Test with a norm different of 1
     model = AbsorbedSpectralModel(
-        spectral_model=pwl, absorption=absorption, alpha_norm=1.5, parameter=redshift
+        spectral_model=pwl, absorption=absorption, alpha_norm=1.5, redshift=redshift
     )
     desired = u.Quantity(2.739695e-13, "TeV-1 s-1 cm-2")
     assert model.alpha_norm.value == 1.5
     assert_quantity_allclose(model(1 * u.TeV), desired, rtol=1e-3)
 
     # Test error propagation
-    model.spectral_model.parameters.set_error(
-        amplitude=0.1 * model.spectral_model.amplitude.value
-    )
+    model.spectral_model.amplitude.error = 0.1 * model.spectral_model.amplitude.value
     dnde, dnde_err = model.evaluate_error(1 * u.TeV)
     assert_allclose(dnde_err / dnde, 0.1)
 
@@ -404,7 +417,7 @@ def test_ecpl_integrate():
 def test_pwl_pivot_energy():
     pwl = PowerLawSpectralModel(amplitude="5.35510540e-11 cm-2 s-1 TeV-1")
 
-    pwl.parameters.covariance = [
+    pwl.covariance = [
         [0.0318377 ** 2, 6.56889442e-14, 0],
         [6.56889442e-14, 0, 0],
         [0, 0, 0],
@@ -469,7 +482,7 @@ class TestNaimaModel:
         val = model(self.e_array)
         assert val.shape == self.e_array.shape
 
-        model.parameters.set_error(amplitude=0.1 * model.amplitude.value)
+        model.amplitude.error = 0.1 * model.amplitude.value
 
         out = model.evaluate_error(1 * u.TeV)
         assert_allclose(out.data, [5.266068e-13, 5.266068e-14], rtol=1e-3)
@@ -531,6 +544,49 @@ class TestNaimaModel:
         val = model(self.e_array)
         assert val.shape == self.e_array.shape
 
+        model.B.value = 3  # update B
+        val_at_2TeV = 5.1985064062296e-16 * u.Unit("cm-2 s-1 TeV-1")
+        value = model(self.energy)
+        assert_quantity_allclose(value, val_at_2TeV)
+
+    def test_ssc(self):
+        import naima
+
+        ECBPL = naima.models.ExponentialCutoffBrokenPowerLaw(
+            amplitude=3.699e36 / u.eV,
+            e_0=1 * u.TeV,
+            e_break=0.265 * u.TeV,
+            alpha_1=1.5,
+            alpha_2=3.233,
+            e_cutoff=1863 * u.TeV,
+            beta=2.0,
+        )
+
+        radiative_model = naima.radiative.InverseCompton(
+            ECBPL,
+            seed_photon_fields=[
+                "CMB",
+                ["FIR", 70 * u.K, 0.5 * u.eV / u.cm ** 3],
+                ["NIR", 5000 * u.K, 1 * u.eV / u.cm ** 3],
+            ],
+            Eemax=50 * u.PeV,
+            Eemin=0.1 * u.GeV,
+        )
+        B = 125 * u.uG
+        radius = 2.1 * u.pc
+        nested_models = {"SSC": {"B": B, "radius": radius}}
+        model = NaimaSpectralModel(radiative_model, nested_models=nested_models)
+        assert_quantity_allclose(model.B.quantity, B)
+        assert_quantity_allclose(model.radius.quantity, radius)
+        val_at_2TeV = 1.6703761561806372e-11 * u.Unit("cm-2 s-1 TeV-1")
+        value = model(self.energy)
+        assert_quantity_allclose(value, val_at_2TeV, rtol=1e-5)
+
+        model.parameters["B"].value = 100
+        val_at_2TeV = 1.441331153167876e-11 * u.Unit("cm-2 s-1 TeV-1")
+        value = model(self.energy)
+        assert_quantity_allclose(value, val_at_2TeV, rtol=1e-5)
+
 
 class TestSpectralModelErrorPropagation:
     """Test spectral model error propagation.
@@ -546,7 +602,7 @@ class TestSpectralModelErrorPropagation:
             alpha=2.44,
             beta=0.25,
         )
-        self.model.parameters.covariance = [
+        self.model.covariance = [
             [1.31e-23, 0, -6.80e-14, 3.04e-13],
             [0, 0, 0, 0],
             [-6.80e-14, 0, 0.00899, 0.00904],
@@ -595,7 +651,7 @@ class TestSpectralModelErrorPropagation:
             lambda_=0.08703226432146616 * u.Unit("TeV-1"),
             reference=1 * u.TeV,
         )
-        model.parameters.covariance = [
+        model.covariance = [
             [0.00204191498, -1.507724e-14, 0.0, -0.001834819, 0.0],
             [-1.507724e-14, 1.6864740e-25, 0.0, 1.854251e-14, 0.0],
             [0.0, 0.0, 0.0, 0.0, 0.0],
