@@ -5,10 +5,12 @@ from numpy.testing import assert_allclose
 from astropy import units as u
 from astropy.table import Table
 from astropy.time import Time
+from gammapy.data.gti import GTI
 from gammapy.modeling.models import (
     ConstantTemporalModel,
+    ExpDecayTemporalModel,
+    GaussianTemporalModel,
     LightCurveTemplateTemporalModel,
-    PhaseCurveTemplateTemporalModel,
     PowerLawSpectralModel,
     SkyModel,
 )
@@ -16,33 +18,6 @@ from gammapy.utils.scripts import make_path
 from gammapy.utils.testing import requires_data
 
 
-@pytest.fixture(scope="session")
-def phase_curve():
-    path = make_path("$GAMMAPY_DATA/tests/phasecurve_LSI_DC.fits")
-    table = Table.read(path)
-    return PhaseCurveTemplateTemporalModel(
-        table, time_0=43366.275, phase_0=0.0, f0=4.367575e-7, filename=str(path)
-    )
-
-
-@requires_data()
-def test_phasecurve_phase(phase_curve):
-    time = 46300.0
-    phase = phase_curve.phase(time)
-    assert_allclose(phase, 0.7066006737999402)
-
-
-@requires_data()
-def test_phasecurve_evaluate(phase_curve):
-    time = 46300.0
-    value = phase_curve.evaluate_norm_at_time(time)
-    assert_allclose(value, 0.49059393580053845)
-
-    phase = phase_curve.phase(time)
-    value = phase_curve.evaluate_norm_at_phase(phase)
-    assert_allclose(value, 0.49059393580053845)
-
-
 # TODO: add light-curve test case from scratch
 # only use the FITS one for I/O (or not at all)
 @pytest.fixture(scope="session")
@@ -58,15 +33,14 @@ def test_light_curve_str(light_curve):
 
 
 @requires_data()
-def test_light_curve_evaluate_norm_at_time(light_curve):
-    val = light_curve.evaluate_norm_at_time(46300)
-    assert_allclose(val, 0.021192223042749835)
+def test_light_curve_evaluate(light_curve):
+    t = Time(59500, format="mjd")
+    val = light_curve(t)
+    assert_allclose(val, 0.015512, rtol=1e-5)
 
-
-@requires_data()
-def test_light_curve_mean_norm_in_time_interval(light_curve):
-    val = light_curve.mean_norm_in_time_interval(46300, 46301)
-    assert_allclose(val, 0.021192284384617066)
+    t = Time(46300, format="mjd")
+    val = light_curve.evaluate(t.mjd, ext=3)
+    assert_allclose(val, 0.01551196, rtol=1e-5)
 
 
 def rate(x, c="1e4 s"):
@@ -84,6 +58,7 @@ def test_time_sampling(tmp_path):
     table = Table()
     table["TIME"] = time
     table["NORM"] = rate(time)
+    table.meta = dict(MJDREFI=55197.0, MJDREFF=0, TIMEUNIT="hour")
     temporal_model = LightCurveTemplateTemporalModel(table)
 
     filename = str(make_path(tmp_path / "tmp.fits"))
@@ -102,26 +77,43 @@ def test_time_sampling(tmp_path):
     )
 
     sampler = u.Quantity((sampler - Time(t_ref)).sec, "s")
+    assert len(sampler) == 2
+    assert_allclose(sampler.value, [12661.65802564, 7826.92991], rtol=1e-5)
 
     table = Table()
     table["TIME"] = time
     table["NORM"] = np.ones(len(time))
+    table.meta = dict(MJDREFI=55197.0, MJDREFF=0, TIMEUNIT="hour")
     temporal_model_uniform = LightCurveTemplateTemporalModel(table)
 
     sampler_uniform = temporal_model_uniform.sample_time(
         n_events=2, t_min=t_min, t_max=t_max, random_state=0, t_delta="10 min"
     )
-
     sampler_uniform = u.Quantity((sampler_uniform - Time(t_ref)).sec, "s")
 
-    assert len(sampler) == 2
     assert len(sampler_uniform) == 2
-    assert_allclose(sampler.value, [12661.65802564, 26.9299098], rtol=1e-5)
     assert_allclose(sampler_uniform.value, [1261.65802564, 6026.9299098], rtol=1e-5)
 
 
+def test_lightcurve_temporal_model_integral():
+    time = np.arange(0, 10, 0.06) * u.hour
+    table = Table()
+    table["TIME"] = time
+    table["NORM"] = np.ones(len(time))
+    table.meta = dict(MJDREFI=55197.0, MJDREFF=0, TIMEUNIT="hour")
+    temporal_model = LightCurveTemplateTemporalModel(table)
+
+    start = [1, 3, 5] * u.hour
+    stop = [2, 3.5, 6] * u.hour
+    gti = GTI.create(start, stop, reference_time=Time("2010-01-01T00:00:00"))
+
+    val = temporal_model.integral(gti.time_start, gti.time_stop)
+    assert len(val) == 3
+    assert_allclose(np.sum(val), 1.0, rtol=1e-5)
+
+
 def test_constant_temporal_model_sample():
-    temporal_model = ConstantTemporalModel(norm=10.0)
+    temporal_model = ConstantTemporalModel()
 
     t_ref = "2010-01-01T00:00:00"
     t_min = "2010-01-01T00:00:00"
@@ -137,44 +129,66 @@ def test_constant_temporal_model_sample():
     assert_allclose(sampler.value, [15805.82891311, 20597.45375153], rtol=1e-5)
 
 
-def test_constant_temporal_model_evaluate_norm_at_time():
-    temporal_model = ConstantTemporalModel(norm=10.0)
-    val = temporal_model.evaluate_norm_at_time(46300)
-    assert_allclose(val, 10.0, rtol=1e-5)
+def test_constant_temporal_model_evaluate():
+    temporal_model = ConstantTemporalModel()
+    t = Time(46300, format="mjd")
+    val = temporal_model(t)
+    assert_allclose(val, 1.0, rtol=1e-5)
 
 
-def test_phase_time_sampling():
-    time_0 = "2010-01-01T00:00:00"
-    phase = np.arange(0, 1, 0.01)
+def test_constant_temporal_model_integral():
+    temporal_model = ConstantTemporalModel()
+    start = [1, 3, 5] * u.day
+    stop = [2, 3.5, 6] * u.day
+    gti = GTI.create(start, stop)
+    val = temporal_model.integral(gti.time_start, gti.time_stop)
+    assert len(val) == 3
+    assert_allclose(np.sum(val), 1.0, rtol=1e-5)
 
-    table = Table()
-    table["PHASE"] = phase
-    table["NORM"] = ph_curve(phase)
-    phase_model = PhaseCurveTemplateTemporalModel(
-        table, time_0=Time(time_0).mjd, phase_0=0.0, f0=2, f1=0.0, f2=0.0
-    )
 
-    t_min = "2010-01-01T00:00:00"
-    t_max = "2010-01-01T08:00:00"
+def test_exponential_temporal_model_evaluate():
+    t = Time(46301, format="mjd")
+    t_ref = 46300 * u.d
+    t0 = 2.0 * u.d
+    temporal_model = ExpDecayTemporalModel(t_ref=t_ref, t0=t0)
+    val = temporal_model(t)
+    assert_allclose(val, 0.6065306597126334, rtol=1e-5)
 
-    sampler = phase_model.sample_time(
-        n_events=2, t_min=t_min, t_max=t_max, random_state=0, t_delta="0.01 s"
-    )
 
-    sampler = u.Quantity((sampler - Time(time_0)).sec, "s")
+def test_exponential_temporal_model_integral():
+    t_ref = Time(55555, format="mjd")
 
-    assert len(sampler) == 2
-    assert_allclose(sampler.value, [8525.00102763, 11362.44044883], rtol=1e-5)
+    temporal_model = ExpDecayTemporalModel(t_ref=t_ref.mjd * u.d)
+    start = [1, 3, 5] * u.day
+    stop = [2, 3.5, 6] * u.day
+    gti = GTI.create(start, stop, reference_time=t_ref)
+    val = temporal_model.integral(gti.time_start, gti.time_stop)
+    assert len(val) == 3
+    assert_allclose(np.sum(val), 0.102557, rtol=1e-5)
+
+
+def test_gaussian_temporal_model_evaluate():
+    t = Time(46301, format="mjd")
+    t_ref = 46300 * u.d
+    sigma = 2.0 * u.d
+    temporal_model = GaussianTemporalModel(t_ref=t_ref, sigma=sigma)
+    val = temporal_model(t)
+    assert_allclose(val, 0.882497, rtol=1e-5)
+
+
+def test_gaussian_temporal_model_integral():
+    temporal_model = GaussianTemporalModel(t_ref=50003 * u.d, sigma="2.0 day")
+    start = [1, 3, 5] * u.day
+    stop = [2, 3.5, 6] * u.day
+    t_ref = Time(50000, format="mjd")
+    gti = GTI.create(start, stop, reference_time=t_ref)
+    val = temporal_model.integral(gti.time_start, gti.time_stop)
+    assert len(val) == 3
+    assert_allclose(np.sum(val), 0.682679, rtol=1e-5)
 
 
 @requires_data()
-def test_to_dict(phase_curve, light_curve):
-
-    out = phase_curve.to_dict()
-    assert out["type"] == "PhaseCurveTemplateTemporalModel"
-    assert len(out["parameters"]) == 5
-    assert out["parameters"][0]["name"] == "time_0"
-    assert "phasecurve_LSI_DC.fits" in out["filename"]
+def test_to_dict(light_curve):
 
     out = light_curve.to_dict()
     assert out["type"] == "LightCurveTemplateTemporalModel"
@@ -182,25 +196,12 @@ def test_to_dict(phase_curve, light_curve):
 
 
 @requires_data()
-def test_with_skymodel(phase_curve, light_curve):
+def test_with_skymodel(light_curve):
 
     sky_model = SkyModel(spectral_model=PowerLawSpectralModel())
     out = sky_model.to_dict()
     assert "temporal" not in out
 
-    sky_model = SkyModel(
-        spectral_model=PowerLawSpectralModel(), temporal_model=phase_curve
-    )
-    sky_model2 = sky_model.copy()
-    assert sky_model2.temporal_model.tag == "PhaseCurveTemplateTemporalModel"
-    assert sky_model2.temporal_model.parameters.names == [
-        "time_0",
-        "phase_0",
-        "f0",
-        "f1",
-        "f2",
-    ]
-
     sky_model = SkyModel(
         spectral_model=PowerLawSpectralModel(), temporal_model=light_curve
     )
