@@ -2,28 +2,36 @@
 """Unit tests for the Fit class"""
 import pytest
 from numpy.testing import assert_allclose
-from gammapy.modeling import Dataset, Fit, Parameter, Parameters
+from gammapy.datasets import Dataset
+from gammapy.modeling import Fit, Parameter
+from gammapy.modeling.models import Model, Models
 from gammapy.utils.testing import requires_dependency
 
 pytest.importorskip("iminuit")
 
 
+class MyModel(Model):
+    x = Parameter("x", 2)
+    y = Parameter("y", 3e2)
+    z = Parameter("z", 4e-2)
+    name = "test"
+    datasets_names = ["test"]
+
+
 class MyDataset(Dataset):
-    def __init__(self, name=""):
+    def __init__(self, name="test"):
         self.name = name
-        self.parameters = Parameters(
-            [Parameter("x", 2), Parameter("y", 3e2), Parameter("z", 4e-2)]
-        )
+        self.models = Models([MyModel()])
         self.data_shape = (1,)
 
     def stat_sum(self):
         # self._model.parameters = parameters
-        x, y, z = [p.value for p in self.parameters]
+        x, y, z = [p.value for p in self.models.parameters]
         x_opt, y_opt, z_opt = 2, 3e2, 4e-2
         return (x - x_opt) ** 2 + (y - y_opt) ** 2 + (z - z_opt) ** 2
 
     def fcn(self):
-        x, y, z = [p.value for p in self.parameters]
+        x, y, z = [p.value for p in self.models.parameters]
         x_opt, y_opt, z_opt = 2, 3e5, 4e-5
         x_err, y_err, z_err = 0.2, 3e4, 4e-6
         return (
@@ -40,9 +48,7 @@ class MyDataset(Dataset):
 def test_run(backend):
     dataset = MyDataset()
     fit = Fit([dataset])
-    result = fit.run(
-        optimize_opts={"backend": backend}, covariance_opts={"backend": backend}
-    )
+    result = fit.run(backend=backend)
     pars = result.parameters
 
     assert result.success is True
@@ -51,13 +57,14 @@ def test_run(backend):
     assert_allclose(pars["y"].value, 3e2, rtol=1e-3)
     assert_allclose(pars["z"].value, 4e-2, rtol=1e-3)
 
-    assert_allclose(pars.error("x"), 1, rtol=1e-7)
-    assert_allclose(pars.error("y"), 1, rtol=1e-7)
-    assert_allclose(pars.error("z"), 1, rtol=1e-7)
+    assert_allclose(pars["x"].error, 1, rtol=1e-7)
+    assert_allclose(pars["y"].error, 1, rtol=1e-7)
+    assert_allclose(pars["z"].error, 1, rtol=1e-7)
 
-    assert_allclose(pars.correlation[0, 1], 0, atol=1e-7)
-    assert_allclose(pars.correlation[0, 2], 0, atol=1e-7)
-    assert_allclose(pars.correlation[1, 2], 0, atol=1e-7)
+    correlation = dataset.models.covariance.correlation
+    assert_allclose(correlation[0, 1], 0, atol=1e-7)
+    assert_allclose(correlation[0, 2], 0, atol=1e-7)
+    assert_allclose(correlation[1, 2], 0, atol=1e-7)
 
 
 @requires_dependency("sherpa")
@@ -66,7 +73,7 @@ def test_optimize(backend):
     dataset = MyDataset()
     fit = Fit([dataset])
     result = fit.optimize(backend=backend)
-    pars = dataset.parameters
+    pars = dataset.models.parameters
 
     assert result.success is True
     assert_allclose(result.total_stat, 0)
@@ -93,13 +100,13 @@ def test_confidence(backend):
     assert_allclose(result["errn"], 1)
 
     # Check that original value state wasn't changed
-    assert_allclose(dataset.parameters["x"].value, 2)
+    assert_allclose(dataset.models.parameters["x"].value, 2)
 
 
 @pytest.mark.parametrize("backend", ["minuit"])
 def test_confidence_frozen(backend):
     dataset = MyDataset()
-    dataset.parameters["x"].frozen = True
+    dataset.models.parameters["x"].frozen = True
     fit = Fit([dataset])
     fit.optimize(backend=backend)
     result = fit.confidence("y")
@@ -119,7 +126,7 @@ def test_stat_profile():
     assert_allclose(result["stat"], [4, 0, 4], atol=1e-7)
 
     # Check that original value state wasn't changed
-    assert_allclose(dataset.parameters["x"].value, 2)
+    assert_allclose(dataset.models.parameters["x"].value, 2)
 
 
 def test_stat_profile_reoptimize():
@@ -127,7 +134,7 @@ def test_stat_profile_reoptimize():
     fit = Fit([dataset])
     fit.run()
 
-    dataset.parameters["y"].value = 0
+    dataset.models.parameters["y"].value = 0
     result = fit.stat_profile("x", nvalues=3, reoptimize=True)
 
     assert_allclose(result["values"], [0, 2, 4], atol=1e-7)
@@ -136,7 +143,7 @@ def test_stat_profile_reoptimize():
 
 def test_minos_contour():
     dataset = MyDataset()
-    dataset.parameters["x"].frozen = True
+    dataset.models.parameters["x"].frozen = True
     fit = Fit([dataset])
     fit.optimize(backend="minuit")
     result = fit.minos_contour("y", "z")
@@ -153,4 +160,4 @@ def test_minos_contour():
     assert_allclose(y[-1], 0.54, rtol=1e-5)
 
     # Check that original value state wasn't changed
-    assert_allclose(dataset.parameters["y"].value, 300)
+    assert_allclose(dataset.models.parameters["y"].value, 300)
