@@ -4,40 +4,30 @@ import hashlib
 import json
 import logging
 import sys
-import yaml
-import multiprocessing
-from urllib.request import urlretrieve, urlopen
 from pathlib import Path
-from .. import version
+from urllib.request import urlopen
+import yaml
+from gammapy import __version__
 
 log = logging.getLogger(__name__)
 
-BASE_URL = "https://gammapy.org/download"
-BASE_URL_DEV = "https://raw.githubusercontent.com/gammapy/gammapy/master/"
-DEV_NBS_YAML_URL = BASE_URL_DEV + "tutorials/notebooks.yaml"
-DEV_SCRIPTS_YAML_URL = BASE_URL_DEV + "examples/scripts.yaml"
-DEV_DATA_JSON_URL = BASE_URL_DEV + "dev/datasets/gammapy-data-index.json"
+RELEASES_BASE_URL = "https://gammapy.org/download"
+DEV_NBS_YAML_URL = (
+    "https://raw.githubusercontent.com/gammapy/gammapy/master/tutorials/notebooks.yaml"
+)
+DEV_SCRIPTS_YAML_URL = (
+    "https://raw.githubusercontent.com/gammapy/gammapy/master/examples/scripts.yaml"
+)
+TAR_BUNDLE = (
+    "https://github.com/gammapy/gammapy-data/tarball/master"  # Curated datasets bundle
+)
+DEV_DATA_JSON_LOCAL = "../../dev/datasets/gammapy-data-index.json"  # CI tests
 
 
-def get_file(ftuple):
-    url, filepath, md5server = ftuple
-
-    retrieve = True
-    if md5server and Path(filepath).exists():
-        md5local = hashlib.md5(Path(filepath).read_bytes()).hexdigest()
-        if md5local == md5server:
-            retrieve = False
-
-    if retrieve:
-        try:
-            urlretrieve(url, filepath)
-        except Exception as ex:
-            log.error(filepath + " could not be copied.")
-            log.error(ex)
-
-
-def parse_datafiles(datasearch, datasetslist):
+def parse_datafiles(datasearch, datasetslist, download_tests=False):
     for dataset in datasetslist:
+        if dataset["name"] == "tests" and not download_tests and datasearch != "tests":
+            continue
         if (datasearch == dataset["name"] or datasearch == "") and dataset.get(
             "files", ""
         ):
@@ -66,36 +56,50 @@ def parse_imagefiles(notebookslist):
 class ComputePlan:
     """Generates the whole list of files to download"""
 
-    def __init__(self, src, outfolder, release, option, modetutorials=False):
+    def __init__(
+        self, src, outfolder, release, option, modetutorials=False, download_tests=False
+    ):
         self.src = src
         self.outfolder = Path(outfolder)
         self.release = release
         self.option = option
         self.modetutorials = modetutorials
+        self.download_tests = download_tests
         self.listfiles = {}
-        log.info("Looking for {}...".format(self.option))
+        log.info(f"Looking for {self.option}...")
+
+        if self.release == "" and "dev" not in __version__:
+            self.release = __version__
 
     def getenvironment(self):
-        filename_env = "gammapy-" + self.release + "-environment.yml"
-        url_file_env = BASE_URL + "/install/" + filename_env
-        filepath_env = str(self.outfolder / filename_env)
         try:
-            log.info("Downloading {}".format(url_file_env))
+            from parfive import Downloader
+        except ImportError:
+            log.error("To use gammapy download, install the parfive package!")
+            return
+
+        dl = Downloader(progress=False, file_progress=False)
+        filename_env = "gammapy-" + self.release + "-environment.yml"
+        url_file_env = RELEASES_BASE_URL + "/install/" + filename_env
+        filepath_env = str(self.outfolder / filename_env)
+        dl.enqueue_file(url_file_env, path=filepath_env)
+        try:
+            log.info(f"Downloading {url_file_env}")
             Path(filepath_env).parent.mkdir(parents=True, exist_ok=True)
-            get_file((url_file_env, filepath_env, ""))
+            dl.download()
         except Exception as ex:
             log.error(ex)
             exit()
 
     def getlocalfolder(self):
-        suffix = "-{}".format(self.release)
+        suffix = f"-{self.release}"
 
         if self.release == "":
-            suffix += version.version
+            suffix += __version__
         if self.option == "notebooks":
-            return self.outfolder / "notebooks{}".format(suffix)
+            return self.outfolder / f"notebooks{suffix}"
         if self.option == "scripts":
-            return self.outfolder / "scripts{}".format(suffix)
+            return self.outfolder / f"scripts{suffix}"
         if self.option == "datasets" and self.modetutorials:
             return self.outfolder / "datasets"
         return self.outfolder
@@ -108,7 +112,7 @@ class ComputePlan:
         else:
             self.listfiles = {}
             if not self.modetutorials:
-                log.warning("{} {} not found".format(filetype, self.src))
+                log.warning(f"{filetype} {self.src} not found")
 
     def getfilelist(self):
         if self.option == "notebooks" or self.modetutorials:
@@ -125,23 +129,41 @@ class ComputePlan:
         if self.option == "datasets":
             if self.modetutorials and not self.listfiles:
                 sys.exit()
-
-            url = DEV_DATA_JSON_URL
+            # datasets bundle
+            if not self.src:
+                self.listfiles = {"bundle": {"path": self.outfolder, "url": TAR_BUNDLE}}
+                return self.listfiles
+            # collection of files
             if self.release:
-                filename_datasets = "gammapy-" + self.release + "-data-index.json"
-                url = BASE_URL + "/data/" + filename_datasets
-
-            log.info("Reading {}".format(url))
-            try:
-                txt = urlopen(url).read().decode("utf-8")
-            except Exception as ex:
-                log.error(ex)
-                return False
-
+                url_datasets_json = (
+                    RELEASES_BASE_URL
+                    + "/data/gammapy-"
+                    + self.release
+                    + "-data-index.json"
+                )
+                log.info(f"Reading {url_datasets_json}")
+                try:
+                    txt = urlopen(url_datasets_json).read().decode("utf-8")
+                except Exception as ex:
+                    log.error(ex)
+                    return False
+            else:
+                # for development just use the local index file
+                local_datasets_json = (
+                    Path(__file__).parent / DEV_DATA_JSON_LOCAL
+                ).resolve()
+                log.info(f"Reading {local_datasets_json}")
+                txt = local_datasets_json.read_text()
             datasets = json.loads(txt)
             datafound = {}
             if not self.modetutorials:
-                datafound.update(dict(parse_datafiles(self.src, datasets)))
+                datafound.update(
+                    dict(
+                        parse_datafiles(
+                            self.src, datasets, download_tests=self.download_tests
+                        )
+                    )
+                )
             else:
                 for item in self.listfiles:
                     record = self.listfiles[item]
@@ -159,9 +181,9 @@ class ComputePlan:
         url = DEV_NBS_YAML_URL
         if self.release:
             filename_nbs = "gammapy-" + self.release + "-tutorials.yml"
-            url = BASE_URL + "/tutorials/" + filename_nbs
+            url = RELEASES_BASE_URL + "/tutorials/" + filename_nbs
 
-        log.info("Reading {}".format(url))
+        log.info(f"Reading {url}")
         try:
             txt = urlopen(url).read().decode("utf-8")
         except Exception as ex:
@@ -187,9 +209,9 @@ class ComputePlan:
         url = DEV_SCRIPTS_YAML_URL
         if self.release:
             filename_scripts = "gammapy-" + self.release + "-scripts.yml"
-            url = BASE_URL + "/tutorials/" + filename_scripts
+            url = RELEASES_BASE_URL + "/tutorials/" + filename_scripts
 
-        log.info("Reading {}".format(url))
+        log.info(f"Reading {url}")
         try:
             txt = urlopen(url).read().decode("utf-8")
         except Exception as ex:
@@ -211,32 +233,46 @@ class ComputePlan:
 class ParallelDownload:
     """Manages the process of downloading files"""
 
-    def __init__(self, listfiles, outfolder, release, option, modetutorials):
+    def __init__(self, listfiles, outfolder, release, option, modetutorials, progress):
         self.listfiles = listfiles
         self.outfolder = outfolder
         self.release = release
         self.option = option
         self.modetutorials = modetutorials
+        self.progress = progress
         self.bar = 0
 
     def run(self):
-        if self.listfiles:
-            log.info("Content will be downloaded in {}".format(self.outfolder))
+        try:
+            from parfive import Downloader
+        except ImportError:
+            log.error("To use gammapy download, install the parfive package!")
+            return
 
-        pool = multiprocessing.Pool(5)
+        if self.listfiles:
+            log.info(f"Content will be downloaded in {self.outfolder}")
+
+        dl = Downloader(progress=self.progress, file_progress=False)
         for rec in self.listfiles:
             url = self.listfiles[rec]["url"]
             path = self.outfolder / self.listfiles[rec]["path"]
             md5 = ""
             if "hashmd5" in self.listfiles[rec]:
                 md5 = self.listfiles[rec]["hashmd5"]
-            ifolder = Path(path).parent
-            ifolder.mkdir(parents=True, exist_ok=True)
-            ftuple = (url, str(path), md5)
-            pool.apply_async(get_file, args=(ftuple,), callback=self.progressbar)
-        pool.close()
-        pool.join()
-        pool.close()
+            retrieve = True
+            if md5 and path.exists():
+                md5local = hashlib.md5(path.read_bytes()).hexdigest()
+                if md5local == md5:
+                    retrieve = False
+            if retrieve:
+                dl.enqueue_file(url, path=str(path.parent))
+
+        log.info(f"{dl.queued_downloads} files to download.")
+        res = dl.download()
+        log.info(f"{len(res)} files downloaded.")
+        for err in res.errors:
+            _, _, exception = err
+            log.error(f"Error: {exception}")
 
     def show_info_datasets(self):
         print("")
@@ -244,31 +280,16 @@ class ParallelDownload:
         if self.modetutorials:
             GAMMAPY_DATA = Path.cwd() / self.outfolder.parent / "datasets"
             if self.release:
-                datafolder = "datasets-" + self.release
-                GAMMAPY_DATA = Path.cwd() / self.outfolder.parent / datafolder
                 print(
                     "*** Enter the following commands below to get started with this version of Gammapy"
                 )
-                print("cd {}".format(self.outfolder.parent))
+                print(f"cd {self.outfolder.parent}")
                 condaname = "gammapy-" + self.release
                 envfilename = condaname + "-environment.yml"
-                print("conda env create -f {}".format(envfilename))
-                print("conda activate {}".format(condaname))
+                print(f"conda env create -f {envfilename}")
+                print(f"conda activate {condaname}")
                 print("jupyter lab")
                 print("")
         print("*** You might want to declare GAMMAPY_DATA env variable")
-        print("export GAMMAPY_DATA={}".format(GAMMAPY_DATA))
+        print(f"export GAMMAPY_DATA={GAMMAPY_DATA}")
         print("")
-
-    def progressbar(self, args):
-        self.bar += 1
-        barLength, status = 50, ""
-        progress = self.bar / len(self.listfiles)
-        if progress >= 1.0:
-            progress, status = 1, "\r\n"
-        block = int(round(barLength * progress))
-        text = "\rDownloading files [{}] {:.0f}% {}".format(
-            "=" * block + "." * (barLength - block), round(progress * 100, 0), status
-        )
-        sys.stdout.write(text)
-        sys.stdout.flush()
