@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Statistics."""
+from .counts_statistic import *
 from .feldman_cousins import *
 from .fit_statistics import *
 from .fit_statistics_cython import *
-from .normal import *
-from .poisson import *
