@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Multi-Gaussian distribution utilities (Gammapy internal)."""
 import numpy as np
-from scipy.optimize import brentq
+import scipy.optimize
 
 
 class Gauss2DPDF:
@@ -114,7 +114,7 @@ class Gauss2DPDF:
 
         Returns
         -------
-        gauss_convolve : `~gammapy.image.models.Gauss2DPDF`
+        gauss_convolve : `~gammapy.modeling.models.Gauss2DPDF`
             Convolution of both Gaussians.
         """
         sigma = np.asarray(sigma, dtype=np.float64)
@@ -240,7 +240,7 @@ class MultiGauss2D:
 
         Returns
         -------
-        norm_multigauss : `~gammapy.image.models.MultiGauss2D`
+        norm_multigauss : `~gammapy.modeling.models.MultiGauss2D`
            normalized function
         """
         sum = self.integral
@@ -302,7 +302,7 @@ class MultiGauss2D:
         # Expand until we really find a theta_max
         while f(theta_max) < 0:
             theta_max *= 2
-        return brentq(f, a=0, b=theta_max)
+        return scipy.optimize.brentq(f, a=0, b=theta_max)
 
     def match_sigma(self, containment_fraction):
         """Compute equivalent Gauss width.
@@ -345,7 +345,7 @@ class MultiGauss2D:
 
         Returns
         -------
-        new_multi_gauss_2d : `~gammapy.image.models.MultiGauss2D`
+        new_multi_gauss_2d : `~gammapy.modeling.models.MultiGauss2D`
             Convolution as new MultiGauss2D
         """
         sigma = np.asarray(sigma, dtype=np.float64)
