@@ -1,10 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import pytest
-from collections import OrderedDict
 from numpy.testing import assert_allclose
 import astropy.units as u
-from astropy.table import Table, Column
-from ..table import table_standardise_units_copy, table_row_to_dict, table_from_row_data
+from astropy.table import Column, Table
+from gammapy.utils.table import (
+    table_from_row_data,
+    table_row_to_dict,
+    table_standardise_units_copy,
+)
 
 
 def test_table_standardise_units():
@@ -34,7 +37,7 @@ def table():
 
 def test_table_row_to_dict(table):
     actual = table_row_to_dict(table[1])
-    expected = OrderedDict([("a", 2), ("b", 2 * u.m), ("c", "yy")])
+    expected = {"a": 2, "b": 2 * u.m, "c": "yy"}
     assert actual == expected
 
 
